********************************************************************************
* Programa de pobreza multidimensional 2018
* Ultima actualización: 31/01/2024
********************************************************************************

*Para correr el programa se requieren:
*1) Correr el programa de Ajuste a cuentas Nacionales
*2) Correr el programa de bases auxiliares

*Las bases de datos de la ENIGH 2018 se pueden descargar en la página de internet del INEGI
*https://www.inegi.org.mx/programas/enigh/nc/2018/#Microdatos.

*El programa contiene dos partes, la primera parte, se requiere ejecutar el programa de Ajuste a cuentas nacionales 2018
* y posteriormente el de pobreza multidimensional 2018.

***************Programa de pobreza multidimensional 2018************************
*************************Nueva metodologia**************************************

* Contenido del archivo:
* 0. Directorios de trabajo
* 1. Pegado de bases de datos
* 2. NBI 
* 3. Educación
* 4. Salud y Seguridad Social
* 5. Tiempo
* 6. Ingreso
* 7. Cálculo de indicador de MMIP
********************************************************************************

clear all
set more off

********************************************************************************
* Módulo 0. Directorios de trabajo
********************************************************************************

*Globals Directorio de bases

gl ruta=        "D:\MMIP 2023\2018"
gl bases=		"$ruta/bases"
gl ingresos=	"$ruta/ingresos"
gl gasto=	    "$ruta/gasto"
gl tmp=			"$ruta/tmp"
gl final=		"$ruta/final"


********************************************************************************
* Módulo 1. Pegado de bases de datos
********************************************************************************

*Abrir la base hogares y pegar con base de vivienda
use "$bases/hogares.dta", clear
merge  m:1 folioviv  using "$bases/viviendas.dta"
drop _merge

gen cve_mun=substr(ubica_geo,1,5)

merge  m:1 cve_mun using "$bases/tarifas_mun.dta"
drop if _merge==2 
drop _merge

*Generar un folio único, de los folios de vivienda y hogares 
egen folio=concat(folioviv foliohog)

*Tamaño de localidad (tam_loc)
label define tam 1"100 mil habitantes y mas" ///
                 2"De 15,000 a 99,999 hab" ///
				 3"De 2,500 a 14,999 hab" ///
				 4"Menos de 2,500 hab"
destring tam_loc, replace 
label values tam_loc tam

*urbano y rural
gen ur_rur_2500=1
replace ur_rur_2500=2 if tam_loc==4
label define ur_rur 1 "Loc. >= 2,500 habs" 2 "Loc. < 2,500 habs"
label value  ur_rur_2500 ur_rur

* municipio y entidad
gen municipio=real(substr(ubica_geo,3,3))
gen entidad=real(substr(ubica_geo,1,2))

*Etiquetar las entidades
label define ent 1	"Aguascalientes" 2 "Baja California" 3 "Baja California Sur" 4 "Campeche" ///
5 "Coahuila" 6 	"Colima" 7 	"Chiapas" 8	"Chihuahua"  9	"Ciudad de México" 10	"Durango"     ///
11	"Guanajuato"  12	"Guerrero"  13	"Hidalgo"  14	"Jalisco" 15	"México"              ///
16	"Michoacán"  17	"Morelos" 18	"Nayarit" 19	"Nuevo León" 20	"Oaxaca"                  ///
21	"Puebla" 22	"Querétaro" 23	"Quintana Roo" 24	"San Luis Potosí"  25	"Sinaloa"         ///
26	"Sonora"  27	"Tabasco" 28	"Tamaulipas" 29	"Tlaxcala" 30	"Veracruz" 31	"Yucatan"32	"Zacatecas"
label value ent ent

label var mun_frio "Municipios en donde los hogares requieren calefacción"
recode mun_frio (.=0)

*Generar una base que contiene variables de vivienda y hogares y las siguientes variables:
save "$final/hogares+Viv.dta", replace

*Se seleccionan las variables de interes
keep folio folioviv foliohog municipio entidad ur_rur_2500 factor upm tam_loc est_dis ubica_geo tarifa_1 tarifa_1A tarifa_1B tarifa_1C tarifa_1D tarifa_1E tarifa_1F mun_frio

save "$final/factexp.dta", replace

* Base de población
use "$bases/poblacion.dta", clear

egen folio=concat(folioviv foliohog)
sort folio

*Eliminar aquellos parentescos que no pertenecen al nucleo familiar
destring parentesco, replace
drop if parentesco>=400 & parentesco <500
drop if parentesco>=700 & parentesco <800

*tamaño de hogar
gen tam_hog=1
collapse (sum) tam_hog, by(folio)
save "$tmp/tamano_hogar.dta", replace

*Abrir la base con variables seleccionadas
use "$final/factexp.dta", clear
merge 1:1 folio using "$tmp/tamano_hogar.dta"
drop _merge


save "$final/factexp.dta", replace

**Pegar el nuevo factor de expansión a la base de hogares con variables
use "$final/hogares+Viv.dta", clear
merge 1:1 folio using "$final/factexp.dta"
drop _merge

*base de datos que concentra variables de vivienda y tamaño de hogar que se utilizan en el MMIP
save "$tmp/hogaresmmip.dta", replace


********************************************************************************
* Módulo 2. NBI
********************************************************************************

********************************************************************************
*2.1 Construcción y cálculo del indicador de espacio y calidad de la vivienda
********************************************************************************

use "$tmp/hogaresmmip.dta", clear

***2.1.1 Calidad de la vivienda, se elaboran indicadores parciales que miden la calidad de muros, pisos y techos de las viviendas. Para ello se asignan valores de acuerdo con la calidad de los materiales y la norma establecida.

*Paredes de la vivienda (Norma: Tabique, ladrillo, block, piedra, cantera, cemento o concreto)
destring mat_pared, replace 
gen Mj = mat_pared

gen AMj=0
*Material de desecho y lámina de cartón=0
replace AMj=0    if (Mj==1 | Mj==2)
*Lámina de asbesto o metálica, carrizo bambú o palma, y embarro o bajareque = 0.25
replace AMj=0.25 if (Mj>2  & Mj<6)
*Madera o adobe = 0.6							 		
replace AMj=0.6  if (Mj==6 | Mj==7)
*Muros de la vivienda (Norma Tabique, ladrillo, block, piedra, cantera, cemento o concreto)
replace AMj=1    if (Mj==8)
label var AMj "Adecuación de muros"

***Techos de la vivienda
destring mat_techos, replace
gen Tj = mat_techos

gen ATj=0
*Material de desecho y lámina de cartón = 0
replace ATj=0   if (Tj==1 | Tj==2)
*Lámina metálica, de asbesto de fibrocemento ondulada, palma o paja, madera o tejamanil y terrado con viguería = 0.5
replace ATj=0.5 if (Tj> 2 & Tj <9)
*Material de techo (Norma: Teja y Losa de concreto o viguetas con bovedilla)
replace ATj=1  if (Tj==9 | Tj==10)
label var ATj "Adecuación de techos"

***
***Material de piso
*Respuestas "&" = no especificado. 
destring mat_pisos, gen(mat_pisos1) force
recode   mat_pisos1(.=0)
gen Pj = mat_pisos1

gen APj=.
*Tierra = 0
replace APj=0    if (Pj==1 | Pj==0)
*Cemento o firme = .5   																
replace APj=0.5  if (Pj==2)
*Madera, mosaico u otro recubrimiento
replace APj=1    if (Pj==3)
label var APj "Adecuación de pisos"

* Índice compuesto de calidad de la vivienda

* Ponderadores de costos de la vivienda basándose en el estudio de  COPLAMAR VIVIENDA (ver documento metodológico)
gen ACVj=(APj*0.15) + (AMj*0.55) + (ATj*0.30)
label var ACVj "Ind compuesto calidad de la vivienda"

***2.1.2 Espacio disponible en la vivienda, se refiere al grado de hacinamiento, 
gen CTj=num_cuarto
gen Dhj=cuart_dorm

*Variable para identificar viviendas donde la cocina también es dormitorio, 1 si la cocina es exclusiva, es decir "sí no se usa como dormitorio"
gen KEhj=0       if (cocina=="2")
replace KEhj=0.6 if (cocina=="1" & cocina_dor=="1")
replace KEhj=1   if (cocina=="1" & cocina_dor=="2")

label var CTj "Cuartos totales viv(cuart)"
label var Dhj "Num. dormitorios hogar(dormi)"

*Generar variable cuartos multiusos 
gen CMj= CTj - (Dhj + KEhj)
label var CMj "Cuartos multiusos viv"

*Para viviendas en las que reside una sola una persona, la norma es 1
gen       CTj_N1=1 if tot_resid ==1
recode    CTj_N1 (.=0)
label var CTj_N1 "Norma cuartos totales para viviendas unipersonales"

*Para viviendas con más de una persona
*Norma de dormitorios-> Un cuarto por cada dos personas				
gen Dh_N = tot_resid/2
label var Dh_N "Norma dormitorios hogar"

*Generar adecuación dormitorios por hogar
gen ADh  = Dhj / Dh_N
label var ADh "Ind Adecuación dormitorios"

*Norma de cuartos multiusos de vivienda -> Un cuarto por cada cuatro personas		
gen CMj_N = tot_resid/4
label var CMj_N "Norma cuarto multiuso vivienda"

*Norma de dormitorios equivalentes para calcular el indicador de adecuación de espacios en la vivienda								
gen DEh_N = (0.5) + Dh_N + (CMj_N*1.5)
label var DEh_N "Norma Dormitorios Equivalentes"

*Número de dormitorios equivalentes 								
gen DEh = (KEhj*0.5) + Dhj + (CMj*1.5)
label var DEh "Número de Dormitorios Equivalentes"

*Generar adecuación de espacios de la vivienda
gen     AEVh = DEh / DEh_N
replace AEVh= CTj/CTj_N1 if tot_resid==1 
label var AEVh "Adec de espacios de la vivienda"

***
*** Cálculo del indicador de espacio disponible en la vivienda
***

*Reescalación de indicador de adecuación de la vivienda
gen  AEVh_P   = AEVh 
replace AEVh_P= 1 + ((AEVh-1)/(2))  if  AEVh >  1
replace AEVh_P= 2 if AEVh_P>=2
label var AEVh_P "Reescal de Adec espacio viv"

gen HMDh = 1 - AEVh_P
label var HMDh "Hacinamiento multidimensional"

***
***Cálculo del consolidado de cantidad y calidad de la vivienda.
***
*Se toman en cuenta ambos indicadores, de espacio y calidad de la vivienda
gen ACEVj = ACVj*AEVh_P
label var ACEVj "Ind de espacio y calidad de la vivienda"
*Generar la variable de carencia
gen CCEVj = 1-ACEVj
label var CCEVj "Ind carencia de espacio y calidad de la vivienda"

******************************************************************
*2.2 Construcción y cálculo del indicador de bienes durables.
******************************************************************

*Se renombran las variables de bienes durables
gen cal_sol=1  if (calent_sol  == "1")
gen cal_gas=1  if (calent_gas== "1")
gen bomag=1    if (bomba_agua=="1")
gen calefac=1  if (calefacc=="1") & mun_frio==1
gen auto      =num_auto
gen camneta   =num_van
gen camcaj    =num_pickup                                 
gen moto      =num_moto                                     
gen bici      =num_bici 
gen estereo   =num_ester
gen radio     =num_radio
gen grabad    =num_grab
gen tv        =num_tva + num_tvd
gen dvd       =num_dvd
gen licuad    =num_licua
gen refri     =num_refri
gen estgas    =num_estuf
gen lavado    =num_lavad
gen plancha   =num_planc
gen mcoser    =num_maqui
gen venti     =num_venti
gen aspirado  =num_aspir
gen compu     =num_compu
gen juegovi   =num_juego
gen tosta     =num_tosta
gen horno     =num_micro
gen impresor  =num_impre

*Cambiar los valores de missing a 0 y de -1 a 0 para poder hacer la deflactación y la suma
recode cal_sol - impresor  (.=0)(-1=0)

*Dato externo 1 = Precios de bienes durables, actualizados a 2018. Véase documento metodológico

*Valores de artículos de vivienda deflactados al mes de agosto de 2018
gen Nauto	 =	147909.03 	*	auto
gen Ncamnet	 =	165764.82 	*	camneta
gen Ncamcaj	 =	165764.72 	*	camcaj
gen Nmoto	 = 	 33551.21 	*	moto
gen Nbici	 =	  1608.37 	*	bici
gen Nradio	 =	   601.01  	*	radio
gen Ngraba	 =	   601.01 	*	graba
gen Nestereo =	  3247.45 	*	estereo
gen Ntv	     =	  4979.61 	*	tv
gen Ndvd	 =	   504.90   *	dvd
gen Njuegov	 =	  5225.74 	*	juegovi
gen Ncompu	 =	  7301.80 	*	compu
gen Nventi	 =	   569.37   *	venti
gen Nmcoser	 =	  3328.01 	*	mcoser
gen Nestgas	 =	  3626.20 	*	estgas
gen Nrefri	 =	  8097.25 	*	refri
gen Nlicuad	 =	   329.25   *	licuad
gen Nbomag	 =	  1107.75 	*	bomag
gen Nplanch	 =	   138.45  	*	plancha
gen Nlavado	 =	  7041.77 	*	lavado
gen Naspira	 =	   554.45   *	aspirado
gen Ncalgas	 =	  2220.35 	*	cal_gas
gen Ncalsol	 =	  7143.45 	*	cal_sol
gen Ncalefac =	   978.08	*	calefac
gen Ntosta	 =	   509.93 	*	tosta
gen Nhorno	 =	  1499.71 	*	horno
gen Nimpresor=	  1579.67 	*	impreso



***Cálculo del indicador de adecuación de bienes durables
*D2
*Dato externo 2 = Canasta de bienes durables
*NORMA es la suma del valor presente de: bicicleta, radio, grabadora, tv, 
*computadora, ventilador, estufa de gas, refrigerador, licuadora, plancha y
*lavadora además para municipios fríos se le suma calentador de gas y calefactor
*Para obtener la carencia se suma de todos los bienes durables y se dividen 
*entre norma, siendo el denominador en 2018, $37,114.44  y $38092.52, para municipios fríos.
************************************************.
gen ABDj= (Nauto +  Ncamnet + Ncamcaj +  Nmoto  + Nbici  + Nradio  + Ngraba+ ///      
Nestereo + Ntv + Nventi + Nmcoser + Nestgas + Nrefri  + Nlicuad + ///
Nbomag + Nplanch + Nlavado + Naspira + Ncalgas + Ndvd + Njuegov + ///
Ncompu + Ncalsol +Ntosta + Nhorno + Nimpresor) / 37114.44 if mun_frio==0

*Para municipios que necesitan calefacción
replace ABDj = (Nauto +  Ncamnet + Ncamcaj +  Nmoto  + Nbici  + Nradio  + Ngraba+ ///      
Nestereo + Ntv + Nventi + Nmcoser + Nestgas + Nrefri  + Nlicuad + ///
Nbomag + Nplanch + Nlavado + Naspira  + Ndvd + Njuegov + ///
Ncompu + Ncalsol +Ntosta + Nhorno + Nimpresor + Ncalgas + Ncalefac) / 38092.52 if mun_frio==1

*Reescalación de variable de adecuación de bienes durables
gen ABDj_P    = ABDj
replace ABDj_P=1 + ((ABDj-1)/ 9) if (ABDj > 1 ) 
replace ABDj_P=2 if ABDj_P>=2
label var ABDj_P "Adec bienes durables reescalado"

*Generación de variable de carencia de bienes durables
gen CBDj = 1 - ABDj_P
label var CBDj "Carenc Adec bienes durables"

******************************************************************
*2.3 Construcción y cálculo del indicador de adecuación sanitaria
******************************************************************

* El indicador tiene tres componentes parciales, adecuación de disponibilidad de agua,
* conexión al drenaje y excusado

***2.3.1 Agua, la norma corresponde a la disponibilidad de agua dentro de la vivienda, con frecuencia diaria.
***
destring disp_agua, gen(agua_disp)
destring dotac_agua, gen(agua_dot)

*Se recodifica variable de disponibilidad de agua
*La norma es agua entubada dentro de la vivienda (código 1)						
recode agua_disp (7 5 4=0)(3 6=1)(2=2)(1=3), gen(Aj)
gen AAj = Aj/3
label var AAj "Adecuación forma de abasto hídrica"

*Se recodifica variable de frecuencia de agua
*La norma es frecuencia diaria (código 1)											
gen Frec_Aguaj = 0
replace Frec_Aguaj= 4   if (agua_dot == 1)
replace Frec_Aguaj= 2.0 if (agua_dot == 2)
replace Frec_Aguaj= 1.2 if (agua_dot == 3)
replace Frec_Aguaj= 0.6 if (agua_dot == 4)
replace Frec_Aguaj= 0.4 if (agua_dot == 5)

label var Frec_Aguaj  "Frecuencia del agua"
gen AFAj = Frec_Aguaj/4
label var AFAj "Adecuación de frecuencia del agua"

*Generar índice de adecuación y frecuencia de agua

gen     AAHj= AAj      if  Aj==0 
replace AAHj= AAj      if  Aj==1
replace AAHj= AAj*AFAj if  Aj==2
replace AAHj= AAj*AFAj if  Aj==3

label var AAHj "Adecuación de abasto hídrico"

***2.3.2 Drenaje y excusado, Norma: excusado exclusivo conectado a drenaje o fosa séptica
***

*Generar índice de adecuación de drenaje
*Se convierten en numéricas las variables relacionadas con drenaje
destring drenaje, replace
*La norma es drenaje conectado a red pública o fosa séptica							
recode drenaje (1 2=1)(3 4 5=0), gen(Drj)
gen ADrj =Drj/1
label var ADrj "Adecuación del drenaje"

*Generar índice de adecuación de excusado
*La norma es que tengan excusado, no compartido y con descarga directa de agua		
gen EXj=.
replace EXj=0 if (excusado=="2")
replace EXj=0 if (sanit_agua=="3")
replace EXj=2 if (uso_compar=="1" & sanit_agua=="2")
replace EXj=3 if (uso_compar=="1" & sanit_agua=="1")
replace EXj=3 if (uso_compar=="2" & sanit_agua=="2")
replace EXj=4 if (uso_compar=="2" & sanit_agua=="1")
gen AEXj = EXj /4                             
label var AEXj "Adecuación del excusado"   

*Generar indicador consolidado de adecuación sanitaria, con base en adecuación de abasto hídrico, de drenaje y de excusado
gen ASj = AAHj * ADrj * AEXj 
label var ASj "Indicador consolidado de adecuación sanitaria"

*Generar indicador de carencia sanitaria
gen CSj = 1 - ASj
label var CSj "Ind de carencia sanitaria"

******************************************************************* 
*2.4 Construcción y cálculo del indicador de servicio de comunicaciones
*******************************************************************

destring telefono celular conex_inte, replace 

*Generación de indicador conjunto de telefonía o celular
* La norma es tener al menos uno de los dos										
gen ATlj =0 		if (telefono == 2 & celular == 2)
replace ATlj =1 	if (telefono == 1 | celular == 1)									
replace ATlj =1.5 	if (telefono == 1 & celular == 1)
label var ATlj "Adecuación telefonía"

*internet
gen Ij=. 
replace Ij= 1 if conex_inte==1
replace Ij= 0 if conex_inte==2
label  var Ij  "Adecuación al internet" 

*Creación del indicador de carencia en el acceso a internet 
gen IVj= 1-Ij 
label var IVj "Ind Carencia de internet"

***Adecuación comunicaciones teléfono fijo o celular y acceso al internet
gen ACTI= (ATlj+Ij)/2
label var ACTI "Adecuación comunicaciones teléfono fijo o celular y acceso al internet"

*Generación de indicador de carencia comunicaciones teléfono fijo o celular y acceso al internet
gen CTELJ = 1 - ACTI
label var CTELJ "Ind carencia del serv. telefónico e internet"

************************************************************************
* 2.5 Construcción y cálculo del indicador de adecuación energética
*************************************************************************

destring disp_elect excusado regadera, replace

gen AElj=.
* no tiene luz electrica 
replace AElj=0     if disp_elect==5 
* de panel solar o de otra fuente
replace AElj=0.5   if disp_elect==3 |  disp_elect==4
*del servicio público o de una planta particular
replace AElj=1     if disp_elect==1 |  disp_elect==2
label var AElj "Indicador logro de acceso a electricidad"

************************************************************************
* 2.5.2  Logro de focos
***********************************************************************
*La norma es 1.25 focos por cuarto considerando en los cuartos totales el baño.
recode focos_inca focos_ahor (.=0)

*Total de focos en la vivienda, suma focos incandescentes y focos ahorradores
gen Focos= focos_inca + focos_ahor
label var Focos "Focos"

*Para  calcular el total de cuartos de la vivienda, primero  se identifica el número de baños en la vivienda (con excusado y regadera, sólo excusado y sólo regadera)
gen cuart_bano=.
recode bano_comp bano_excus bano_regad (.=0)
gen num_bano= bano_comp +bano_excus+ bano_regad

*se construye el total de cuartos de la vivienda contando cocina y baños
gen CTBj=CTj+ num_bano 
label var CTBj "Cuartos totales de la vivienda + baño"

*Número de focos observados en el hogar: donde el mínimo absoluto es un foco por cuarto (umbral adecuado para identificar pobreza extrema) pero ciertas actividades requiere luz intensa, así que un promedio de 1.25 focos por cuarto parecen un lumbral adecuado.
gen Fj_N=1.25
label var Fj "Focos normativos por cuarto incluyendo baños"

*Indicador logro de focos
gen LFj=(Focos/CTBj)/Fj_N
label var LFj "Indicador logro de focos"

*Reescalar para que el máximo del indicador de logro sea 2 
gen LFj_P=LFj
replace LFj_P=1+[(LFj-1)/(3)] if LFj>1
replace LFj_P=2 if LFj_P>=2
label var LFj_P "Indicador logro de focos rescalado"

*Indicador integral de logro de electricidad 
gen LIEI= AElj*LFj_P
label var LIEI "Indicador integral de logro de electricidad"

*Indicador de privación de electricidad integral 
gen PIEI=1-LIEI
label var PIEI "Indicador de privación de electricidad integral"

************************************************************************
* 2.5.3  Fuente de energía para cocinar
***********************************************************************

** Códigos en la ENIGH de variable combustible y valores para el cálculo:
**1 Leña, 2 Carbón,  6 Otro combustible= 0.33
** 3 Gas de tanque, 4 Gas natural o de tubería y 5 Electricidad===1 (norma)

gen CK=.
replace CK=3 if (combustible == "3" | combustible == "4" | combustible == "5" )
* La norma es utilizar gas o electricidad para cocinar 									
replace CK=1 if (combustible == "1" | combustible == "2" | combustible == "6" | combustible == "&" )

gen ACK=(CK/3)
label var ACK "Indicador de adecuación combustible"

gen PCK= 1 - ACK
label var PCK "Indicador de privación de combustible"

gen AENj= ACK*(0.30) + LIEI*(0.70)
label var AENj "Adecuación energética"  

*Carencia de adecuación energética
gen CENj=1-AENj
label var CENj "Indicador de Carencia energética"

keep folio AMj  ATj APj ACVj ADh AEVh AEVh_P HMDh ACEVj CCEVj ABDj_P CBDj AAj AFAj AAHj ADrj AEXj ASj CSj ATlj Ij IVj ACTI CTELJ AElj  CTBj LFj_P LIEI  PIEI  ACK PCK AENj CENj upm

save "$final/nbi.dta", replace 

********************************************************************************
* Módulo 3. Educación
*
*  3.1 Años de escolaridad
*  3.2 Condición de analfabetismo
*  3.3 Cálculo del indicador de adecuación y rezago educativo 

********************************************************************************

*Abrir la base de población 
use "$bases/poblacion.dta", clear

keep if edad>=3

*Se crea el identificador "folio"
egen folio= concat(folioviv foliohog)
sort folioviv foliohog numren

*Se eliminan los que no son miembros de la familia  
destring edad parentesco, replace 
drop if parentesco>=400 & parentesco<500
drop if parentesco>=700 & parentesco<800

* Tanto alfabetización (alfabetism) como asistencia escolar (asis_esc)
*	está codificadas de la siguiente manera: 1=si  2 = no
destring nivelaprob gradoaprob antec_esc alfabetism asis_esc, replace

gen asis_escia = asis_esc

************************
*3.1 Años de escolaridad
************************

***
***Rescalación de años de escolaridad
***

* Generar la variable rescgeni
gen rescgeni=0


*Paso 1: Se reemplaza el grado aprobado que tiene
	*la persona según su edad, comenzando con preescolar.
replace rescgeni=1 if nivelaprob==1 & gradoaprob==1 
replace rescgeni=2 if nivelaprob==1 & gradoaprob==2
replace rescgeni=3 if nivelaprob==1 & gradoaprob==3

*Paso 2: Si el nivel aprobado es primaria, secundaria o bachillerato, se les suma la cantidad de años que debió haber estudiado previamente,
* de manera que, en suma, se obtenga el número de años que llevan estudiando, tomando en cuenta preescolar.
replace rescgeni=(2 + (gradoaprob+1)) if nivelaprob==2
replace rescgeni=(3 + (gradoaprob+6)) if nivelaprob==3
replace rescgeni=(4 + (gradoaprob+8)) if nivelaprob ==4

*Paso 3: Al grado "normal" o "carrera técnica",
* se les suma el número de años dependiendo del antecedente escolar (secundaria o media superior)

replace rescgeni=10 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==1 & antec_esc==1) 
replace rescgeni=11 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==2 & antec_esc==1)
replace rescgeni=12 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==3 & antec_esc==1)
replace rescgeni=13 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==4 & antec_esc==1) 
replace rescgeni=14 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==5 & antec_esc==1) 

replace rescgeni=13 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==1 & antec_esc==2)
replace rescgeni=14 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==2 & antec_esc==2) 
replace rescgeni=15 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==3 & antec_esc==2) 
replace rescgeni=16 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==4 & antec_esc==2)
replace rescgeni=17 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==5 & antec_esc==2)
 
replace rescgeni=16 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==1 & antec_esc==3) 
replace rescgeni=17 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==2 & antec_esc==3)
replace rescgeni=18 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==3 & antec_esc==3)
replace rescgeni=19 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==4 & antec_esc==3)
replace rescgeni=20 if ((nivelaprob==6 | nivelaprob==5) & gradoaprob==5 & antec_esc==3)
 
*Paso 4: Si el nivel aprobado es profesional, maestría o doctorado, solo se le suman los años que llevan estudiando 
replace rescgeni=((7 * 2) + (gradoaprob+1)) if (nivelaprob==7 ) 
replace rescgeni=((8 * 2) + (gradoaprob+4)) if (nivelaprob==8 )
replace rescgeni=((9 * 2) + (gradoaprob+4)) if (nivelaprob==9 )
 
 
***
*** Norma educativa de años estudiados, de acuerdo a la edad
***

*Generar variable que identifica el año de nacimiento
gen a_nacimiento= 2018-edad

*Generación variable de norma educativa																	
gen 	normaeduia=.
*9 años  de educación equivalen a primaria
replace normaeduia=  9 if 				a_nacimiento <= 1946
*12 años de educación equivalen a secundaria   				        				 	  
replace normaeduia=	12 if 				a_nacimiento >= 1947 & a_nacimiento 	<= 1976  
*15 años de educación equivalen a media superior   		        				 	 
replace normaeduia=	15 if 				a_nacimiento >= 1977 & edad>=18					
*Norma para los de 5 a 8 años
replace normaeduia= 	edad-4 if 		edad >=5  & edad<=18
*Para los de 3 la normaeduia debe ser 0
replace normaeduia=0 if edad==3 | edad==4

label var normaeduia"Norma educativa"

*3.2 Condición de analfabetismo

***Analfabetismo
*Generar una nueva variable para condición de alfabetismo,
	*donde normaivamente se asume que mayores de ocho años analfabetas están en carencia				<- Normagen Ali=0
gen Ali=0
replace Ali=1 if alfabetism==1
replace Ali=0 if (alfabetism==2 & edad >=8) 
label var Ali "Condición de alfabetismo"

***Asistencia Escolar

*Generación de asistencia escolar
recode asis_escia(1=1) (2=0)

*Generar variable de norma de asistencia, donde los de cuatro  años o más y las personas de hasta los 18 años de edad, con estudios de nivel de bachillerato o preparatoria inconclusos
	*tienen que asistir a la escuela, en términos normativos. En caso contrario, están en carencia.		<- Norma
gen normaasisia=0																						
replace normaasisia=1 if (edad >=4  & edad <=17) 
replace normaasisia=1 if  edad ==18 & rescgeni<=14
replace normaasisia=0 if  edad ==18 & rescgeni==15

* 3.3 Cálculo del indicador de adecuación y rezago educativo   

***Generación de indicador de adecuación de educación

gen     ANEi=((rescgeni+ asis_escia)/ (normaeduia+ normaasisia)) * Ali
replace ANEi=((rescgeni+ asis_escia)/ (normaeduia+ normaasisia)) if (edad>2 & edad<8)
*****Para los niños de 3 años que no asisten a la escuela su ANEI es igual 1 
replace ANEi=1 if edad==3
label var ANEi "Adecuación de educación"

*Se rescala el indicador de ANEi (adecuación de educación), solo para los que están por arriba de la norma

*Se introducen valores de reescalación
gen     ANEi_P=ANEi
replace ANEi_P = 1 + ((ANEi - 1) / (1.667 -1)) if ( ANEi>1 & (edad >= 19  & edad  <= 44) )
replace ANEi_P = 1 + ((ANEi - 1) / (2.083 -1)) if ( ANEi>1 & (edad >= 45 & edad  <= 73) ) 
replace ANEi_P = 1 + ((ANEi - 1) / (2.778 -1)) if ( ANEi>1 & edad > 73)
replace ANEi_P=2 if ANEi_P>2
label var ANEi_P "Adecuación de educación del individuo"


*Generar variable de rezago educativo individual
gen Rei=  1 - ANEi_P 
label var Rei"Rezago educativo individual"

save "$tmp/rei_persona.dta", replace

*******************************************************************************
*para menores de 3 se le imputa su valor de su hogar
*******************************************************************************

*Por hogar
use  "$tmp/rei_persona.dta", clear

egen Rei_p=mean(Rei), by (folio)
keep if parentesco==101
keep folio numren Rei_p 
save "$tmp/rei_hogar.dta", replace

use "$bases/poblacion.dta", clear 
egen folio=concat (folioviv foliohog)
*Se eliminan los que no son miembros de la familia en el hogar
destring parentesco, replace
drop if parentesco>=400 & parentesco <500
drop if parentesco>=700 & parentesco <800
drop parentesco
destring nivelaprob gradoaprob antec_esc alfabetism asis_esc, replace

merge 1:1 folio numren using  "$tmp/rei_persona.dta"
drop _merge

merge m:1 folio using  "$tmp/rei_hogar.dta"
drop _merge

gen Rei1=Rei
replace Rei1=Rei_p if edad<3

keep folio rescgeni ANEi ANEi_P Rei1  numren 

rename Rei1 Rei 

label var rescgeni "Años de escolaridad del individuo"
label var Rei "Rezago educativo del individuo "


save "$final/edu.dta", replace

*****************************************************************************
*Módulo 4. Variables para el cálculo de la pobreza de ingresos
********************************************************************************

*4.1  Construcción de Adulto equivalente
********************************************************************************
*Abrir la base datos, y solo dejamos variables de edad sexo y parentesco 
use "$bases/poblacion.dta", clear 
keep folioviv foliohog edad sexo parentesco
sort folioviv foliohog 
egen folio=concat (folioviv foliohog)

merge m:1 folio using "$final/factexp.dta"
drop _merge

*Se elimina los que no son miembros del hogar
destring parentesco, replace
drop if parentesco>=400 & parentesco <500
drop if parentesco>=700 & parentesco <800

*Se agrupan las personas por edad, sexo y medio (urbano o rural)
gen bebe=1 if edad>=0 & edad<=2
gen nino=1 if edad>=3 & edad<=14
gen adulto=1 if edad>=15 

*Adulto Equivalente Urbano
gen AE=.
replace AE=0.40 if bebe==1 & sexo=="1"
replace AE=0.39 if bebe==1 & sexo=="2"
replace AE=0.56 if nino==1 & sexo=="1"
replace AE=0.55 if nino==1 & sexo=="2"
replace AE=1.00 if adulto==1 & sexo=="1"
replace AE=0.81 if adulto==1 & sexo=="2"

*Adulto Equivalente Rural
replace AE=0.47 if bebe==1 & sexo=="1" & tam_loc==4
replace AE=0.45 if bebe==1 & sexo=="2" & tam_loc==4
replace AE=0.65 if nino==1 & sexo=="1" & tam_loc==4
replace AE=0.63 if nino==1 & sexo=="2" & tam_loc==4
replace AE=1.00 if adulto==1 & sexo=="1" & tam_loc==4
replace AE=0.83 if adulto==1 & sexo=="2" & tam_loc==4

*Identificador de individuo
gen N=1

*Se colapsan las variables por hogar
collapse (sum) AE N, by(folio)
rename N N_BREAK

save "$tmp/adultos_equivalentes.dta", replace

*****************************************************************************
*4.2 Construcción del ingreso total 
********************************************************************************
*Se utiliza la base de datos de ingresos ajustados a cuentas nacionales disponible en 
* la página web del Consejo de Evaluación de la Ciudad de México

use  "$bases/base_final_ACN.dta", clear

*La base de datos incluye todos los tipos de ingresos monetarios y no monetarios ajustados a
*cuentas nacionales, con los que cuales se genera la variable de ingreso total, constituido
*por las remuneraciones, la renta imputada de la vivienda, ganacias (EBO), renta de la
*propiedad y transferencias


*ingreso total ya incluye los ingresos monetarios y no monetarios ajustado a cuentas nacionales
gen double ing_total=remun+imp_viv+EBO+transf+renta
label var  ing_total          "Ingreso corriente total mensual ajustado a cuentas nacionales"

rename p034_ACN YIDj 
rename p035_ACN YISj 
rename p036_ACN YISj2 

*Etiquetar variables
label var YIDj 					"Indemn. por seguros contra riesgos a terceros"
label var YISj 					"Indemn. por accidentes de trabajo"
label var YISj2 				"Indemn. por despido y retiro involuntario"

save "$ingresos/ict.dta", replace

********************************************************************************
*4.3  Construcción de los gastos que se deducen al ingreso por persona
********************************************************************************

*Abrir base de gastos por persona
use "$bases/gastospersona.dta",clear

*Generar Folio
egen folio=concat (folioviv foliohog)

*Generar decena de levantamiento
gen decena= substr(folio,8,1)
destring decena, replace
recode decena ///
	(0/1 = 8 “Agosto”) ///
	(2/4 = 9 “Septiembre”) ///
	(5/7 = 10 “Octubre”) ///
	(8/9 = 11 “Noviembre”), ///
	gen (meslevan) label (meslevan)


*gasto que se deducen por persona por haberse verificado su satisfacción por NBI e ingreso no monetario (remuneraciones en especie)
gen dummying =.
*Gastos en educación 
replace dummying = 1 if (clave >= "E001" & clave <= "E013")                                         
*Gastos de la vivienda 
replace dummying = 1 if (clave == "G001" | clave == "G002" |  clave=="G003" |  clave=="G004")  
*Enseres domésticos                                                                                    
replace dummying = 1 if (clave == "K001" | clave == "K005" | clave == "K007"  | clave == "K008" |   ///  
                         clave == "K009" | clave == "K010" | clave == "K012"  | clave == "K014" |   ///
						 clave == "K015" | clave == "K016" | clave == "K017"  | clave == "K024" ) 
*Artículos de esparcimiento
replace dummying = 1 if (clave == "L001" | clave == "L002" | clave == "L003"  | clave == "L004"  |  ///   
                         clave == "L005" | clave == "L006" | clave == "L007"  | clave == "L008" |  ///  
						 clave == "L009" | clave == "L024" )                                        
replace dummying = 1 if (clave == "M007" | clave == "M008" | clave == "M009"  | clave == "M010")  
recode dummying (.=0)

gen double g1_gasto=gasto_tri    if dummying==1  & tipo_gasto=="G1"
gen double g4_gasto=gas_nm_tri   if dummying==1  & tipo_gasto=="G4"

recode g1_gasto-g4_gasto (.=0)

*Deflactor del INPC tomado de INEGI 2018
gen deflac=0
replace deflac = 1.000000000 if meslevan==8
replace deflac = 1.004229192 if meslevan==9
replace deflac = 1.009433587 if meslevan==10
replace deflac = 1.018021335 if meslevan==11


*Gasto G1 y G4 deflactado
gen double g1_gasto_def = (((g1_gasto) / deflac)/3)
gen double g4_gasto_def = (((g4_gasto) / deflac)/3)
recode g1_gasto_def g4_gasto_def (.=0)

collapse (sum) g1_gasto_def g4_gasto_def , by(folio)

rename g1_gasto_def g1p_gasto
rename g4_gasto_def g4p_gasto

label var g1p_gasto "Suma de gastos monetarios para deducir de bienes y servicios para el hogar"
label var g4p_gasto "Suma de gastos no monetarios para deducir de remuneraciones en especie"

save "$gasto/hogparadeducido_personas.dta", replace 
	
********************************************************************************
*4.4  Construcción del gasto que se deduce del ingreso del gasto hogar
********************************************************************************
	

*Abrir la base de Gastos por hogar
use "$bases/gastoshogar.dta",clear 

*Generar Folio
egen folio=concat (folioviv foliohog)

*Generar decena de levantamiento
gen decena= substr(folio,8,1)
destring decena, replace
recode decena ///
	(0/1 = 8 “Agosto”) ///
	(2/4 = 9 “Septiembre”) ///
	(5/7 = 10 “Octubre”) ///
	(8/9 = 11 “Noviembre”), ///
	gen (meslevan) label (meslevan)

*identifica los rubros para deducir
gen dummying =.
*Gastos en educación 
replace dummying = 1 if (clave >= "E001" & clave <= "E013")                                         
*Gastos de la vivienda 
replace dummying = 1 if (clave == "G001" | clave == "G002" |  clave=="G003" |  clave=="G004")  
*Enseres domésticos                                                                                    
replace dummying = 1 if (clave == "K001" | clave == "K005" | clave == "K007"  | clave == "K008" |   ///  
                         clave == "K009" | clave == "K010" | clave == "K012"  | clave == "K014" |   ///
						 clave == "K015" | clave == "K016" | clave == "K017"  | clave == "K024" ) 
*Artículos de esparcimiento
replace dummying = 1 if (clave == "L001" | clave == "L002" | clave == "L003"  | clave == "L004"  |  ///   
                         clave == "L005" | clave == "L006"  | clave == "L007"  | clave == "L008" |  ///  
						 clave == "L009" | clave == "L024" )                                        
replace dummying = 1 if (clave == "M007" | clave == "M008" | clave == "M009"  | clave == "M010")    
recode  dummying (.=0)

gen double g1_gasto=gasto_tri    if (dummying==1 & (tipo_gasto=="G1" | tipo_gasto=="G2"))
gen double g3_gasto=gas_nm_tri   if (dummying==1 & (tipo_gasto>"G2"))
recode g1_gasto g3_gasto (.=0)	
	
*Deflactor del INPC tomado de INEGI 2018
gen deflac=0
replace deflac = 1.000000000 if meslevan==8
replace deflac = 1.004229192 if meslevan==9
replace deflac = 1.009433587 if meslevan==10
replace deflac = 1.018021335 if meslevan==11

*Gasto G1 y G4 deflactado
gen double g1_gasto_def = (((g1_gasto) / deflac)/3)
gen double g3_gasto_def = (((g3_gasto) / deflac)/3)
recode g1_gasto_def  g3_gasto_def (.=0)

collapse (sum)  g1_gasto_def  g3_gasto_def, by(folio)

rename g1_gasto_def g1h_gasto 
rename g3_gasto_def g3h_gasto 

label var g1h_gasto "Suma de gastos monetarios para deducir de bienes y servicios  para el hogar y otros"
label var g3h_gasto "Suma de gastos no monetarios para deducir autoc,regalos, transf,alq"

save "$gasto/hogparadeducido_hogares.dta", replace 	
	
********************************************************************************
* 4.5 Construcción del monto de Renta mensual deflactada
********************************************************************************

*Utilizar la base de datos de vivienda, a nivel hogar
use "$tmp/hogaresmmip.dta", clear

gen decena= substr(folioviv,8,1)
destring decena, replace
recode decena ///
	(0/1 = 8 "Agosto") ///
	(2/4 = 9 "Septiembre") ///
	(5/7 = 10 "Octubre") ///
	(8/9 = 11 "Noviembre"), ///
	gen (meslevan) label (meslevan)

*Cambiar los valores perdidos a cero
recode renta  estim_pago (.=0)	
	
*Deflactar según el mes de levantamiento de la encuesta

gen deflac=0
replace deflac = 1.000000000 if meslevan==8
replace deflac = 1.004229192 if meslevan==9
replace deflac = 1.009433587 if meslevan==10
replace deflac = 1.018021335 if meslevan==11	
gen double renta_d = (renta/deflac)

keep folio renta_d
label var renta_d "Monto de la renta mensual"

save "$gasto/renta_deducida.dta", replace 


******************************************************************************
*4.6 Construcción del ingreso disponible ajustado
******************************************************************************

use "$final/factexp.dta",clear 
recode tarifa_1 tarifa_1A tarifa_1B tarifa_1C tarifa_1D tarifa_1E tarifa_1F (.=0)

merge 1:1 folio using "$ingresos/ict.dta"
drop _merge
merge 1:1 folio using "$gasto/hogparadeducido_personas.dta"
drop _merge
merge 1:1 folio using "$gasto/hogparadeducido_hogares.dta"
drop _merge
merge 1:1 folio using "$gasto/renta_deducida.dta"
drop _merge

recode tran_gobACN-renta_d(.=0)
save "$ingresos/ingtotal.dta", replace 

*se abre la base de datos
use "$ingresos/ingtotal.dta", clear

*Suma de los gastos a deducir
gen double dedu1=g1p_gasto+ g4p_gasto+ g1h_gasto+ g3h_gasto+renta_d+imp_viv
label var dedu1 "Suma de gastos mensual NBI deflactado agosto "

*Se cambian valores perdidos por ceros
recode YIDj YISj YISj2 (.=0)

*Se redefine el ingreso, quitando las indemizaciones (las cuáles son pagos únicos y no corrientes)
gen double yctrj = ing_total-(YISj + YIDj + YISj2)- (p009_ACN + p016_ACN)

label var yctrj "Ing Corr Tot Mensual Hogar Redefinido"
recode yctrj (.=0)

*Ingreso corriente mensual restando el gasto deducible (excepto salud)
gen double yctradj = yctrj-dedu1
label var yctradj "Ingreso corr total mensual restando deducible excp. salud"

********************************************************************************
********************************************************************************
*Ingresos sin transferencias gubernamentales

*ingreso corriente total mensual
gen double ing_men_hog=yctrj
label var ing_men_hog "ingreso corriente total mensual por hogar"

*ingreso sin trasferencias públicas
gen double ing_men_hog_stp= ing_men_hog-tran_gobACN
label var ing_men_hog_stp "ingreso corriente total mensual por hogar sin transferencias públicas"

*ingreso corriente total mensual per cápita
gen double ing_men_per= ing_men_hog/tam_hog
label var ing_men_per"ingreso corriente total mensual por hogar per cápita"

*ingreso corriente total promedio mensual per cápita sin transferencias
gen double ing_men_stp_per=ing_men_hog_stp/(tam_hog)
label var  ing_men_stp_per "ingreso corriente total mensual por hogar sin transferencias per cápita"

********************************************************************************
********************************************************************************

*Se une con la base de Adulto Equivalente
merge 1:1 folio using "$tmp/adultos_equivalentes.dta"
drop _merge

*se guarda la base 
save "$ingresos/ing_cor_tot.dta", replace 

******************************************************************************
*4.7 Gasto de salud
*****************************************************************************

*Abrir la base de Gastos por hogar
use "$bases/gastoshogar.dta",clear 

keep if tipo_gasto=="G1"

*Generar Folio
egen folio=concat (folioviv foliohog)

gen decena= substr(folioviv,-3,1)
destring decena, replace
recode decena ///
	(0/1 = 8 "Agosto") ///
	(2/4 = 9 "Septiembre") ///
	(5/7 = 10 "Octubre") ///
	(8/9 = 11 "Noviembre"), ///
	gen (meslevan) label (meslevan)

*Gastos de salud 
gen dummyg = 0
replace dummyg=1 if (clave >= "J001"  & clave <= "J072")  

gen double j000=gasto_tri if dummyg==1
recode j000 (.=0)

*Deflactar según el mes de levantamiento de la encuesta 
gen deflac=0
replace deflac = 1.000000000 if meslevan==8
replace deflac = 1.004229192 if meslevan==9
replace deflac = 1.009433587 if meslevan==10
replace deflac = 1.018021335 if meslevan==11
	
gen double def_j000 = (((j000)/ deflac)/3)
recode def_j000 (.=0)

label var def_j000 "Suma de gastos mensual en salud deflactados "
collapse (sum) def_j000, by(folio)	

save "$gasto/j000_18.dta", replace 

********************************************************
* 4.8  Líneas de pobreza
********************************************************
*Abrir la base de ingresos recién guardada

use "$ingresos/ing_cor_tot.dta", replace
merge 1:1 folio using "$gasto/j000_18.dta"
drop _merge	
	
recode  tran_gobACN-def_j000 (.=0)
replace yctradj=0 if yctradj<0

* Lineas de pobreza urbana y rural 
* LP_N=a+(b*tam_hog)+(c* AE)

gen x=1 if tarifa_1==1 | tarifa_1A==1  | tarifa_1B==1 |  tarifa_1C==1 | tarifa_1D==1 | tarifa_1E==1 | tarifa_1F==1

gen LP_N=.	

*Tarifa1										
replace LP_N	=	1381.67	+	(480.29	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1==1
replace LP_N	=	1367.97	+	(480.15	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1==1
*Tarifa 1A										
replace LP_N	=	1376.55	+	(479.12	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1A==1
replace LP_N	=	1362.86	+	(478.98	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1A==1
*Tarifa 1B										
replace LP_N	=	1396.28	+	(473.47	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1B==1
replace LP_N	=	1382.59	+	(473.33	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1B==1
*Tarifa 1C										
replace LP_N	=	1408.29	+	(471.54	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1C==1
replace LP_N	=	1394.60	+	(471.40	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1C==1
*Trarifa 1D										
replace LP_N	=	1415.20	+	(470.23	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1D==1
replace LP_N	=	1401.51	+	(470.09	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1D==1
*Trarifa 1E										
replace LP_N	=	1412.88	+	(469.41	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1E==1
replace LP_N	=	1399.19	+	(469.27	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1E==1
*Trarifa 1F										
replace LP_N	=	1412.88	+	(469.41	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1F==1
replace LP_N	=	1399.19	+	(469.27	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1F==1



*Tarifa1											
replace LP_N	=	1416.95	+	(481.33	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1==1	& mun_frio==1
replace LP_N	=	1403.26	+	(481.19	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1==1	& mun_frio==1
*Tarifa 1A											
replace LP_N	=	1407.26	+	(480.46	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1A==1	& mun_frio==1
replace LP_N	=	1393.57	+	(480.32	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1A==1	& mun_frio==1
*Tarifa 1B											
replace LP_N	=	1416.87	+	(475.40	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1B==1	& mun_frio==1
replace LP_N	=	1403.17	+	(475.26	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1B==1	& mun_frio==1
*Tarifa 1C											
replace LP_N	=	1426.96	+	(473.74	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1C==1	& mun_frio==1
replace LP_N	=	1413.27	+	(473.60	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1C==1	& mun_frio==1
*Trarifa 1D											
replace LP_N	=	1425.33	+	(472.61	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1D==1	& mun_frio==1
replace LP_N	=	1411.64	+	(472.47	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1D==1	& mun_frio==1
*Trarifa 1E											
replace LP_N	=	1423.33	+	(471.82	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1E==1	& mun_frio==1
replace LP_N	=	1409.63	+	(471.68	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1E==1	& mun_frio==1
*Trarifa 1F											
replace LP_N	=	1423.33	+	(1423.33	* tam_hog)	+ (	3548.39	* AE)	if ur_rur_2500==1 & tarifa_1F==1	& mun_frio==1
replace LP_N	=	1409.63	+	(471.68	* tam_hog)	+ (	3207.10	* AE)	if ur_rur_2500==2 & tarifa_1F==1	& mun_frio==1

save "$tmp/cict.dta", replace	


********************************************************************************
*Módulo 5. Seguridad social y salud 
********************************************************************************

********************************************************************************
*SEGURIDAD SOCIAL con servicios completos (pensiones, jubilaciones y salud) 
*y los cubiertos por programas como adultos mayores y discapacidad
********************************************************************************

***5.1 Generación de indicador de ingresos por pensiones y programas de adultos mayores

*Abrir la base de datos de ingresos
use "$bases/ingresos.dta", clear

*Se mantienen solo los datos de ingresos por pensiones (P033 y P032) y de Programas de Adultos Mayores (P044 y P045)
keep if clave =="P032"| clave =="P033" | clave =="P044"  | clave =="P045" 

*Se mantiene en la base solo algunas variables, y se genera la variable folio
keep folioviv foliohog numren clave ing_tri
egen folio= concat(folioviv foliohog)
sort folio numren 

*Identificar cuántos hogares tienen ingresos por pensiones
gen pen032=0
replace pen032=1 if clave=="P032" & ing_tri > 0

gen pen033=0
replace pen033=1 if clave=="P033" & ing_tri > 0

gen pen044=0
replace pen044=1 if clave=="P044"& ing_tri > 0

gen pen045=0
replace pen045=1 if clave=="P045"& ing_tri > 0

label var pen032 "Jubilación dentro del país"
label var pen033 "Jubilación de otros países"
label var pen044 "Beneficio del programa 65 y más"
label var pen045 "Beneficio de otros programas para adultos mayores"

*Colapsar a nivel población dejando 1 como identificador en cada persona que percibe alguno de estos tipos de ingresos
collapse (max) pen032 pen033 pen044 pen045, by(folio numren)

*Abrir la base de datos de pensiones a nivel persona
save "$tmp/Pensiones18.dta", replace 

*Generar la base de población para unirse a la anterior de pensiones
use "$bases/poblacion.dta", clear

*Se genera la variable folio
egen folio= concat(folioviv foliohog)
sort folio numren 

*Se eliminan los que no son miembros de la familia en el hogar
destring parentesco, replace
drop if parentesco>=400 & parentesco <500
drop if parentesco>=700 & parentesco <800

*Se une a la base de factor
merge m:1 folio using "$final/factexp.dta"
drop _merge

*Se une con la base de pensiones
merge 1:1 folio numren using "$tmp/Pensiones18.dta"
drop _merge

*Identificación de las personas con ingresos por jubilación
gen asegsoc_jub=1 if (pen032==1 | pen033==1)
recode asegsoc_jub (.=0)

*Indentificación de las personas beneficiarias de programas sociales como Adultos mayores
gen asegsoci_b=0 
*Se asigna valor según si es beneficiario de programa de adultos mayores o programas estatales para adultos mayores.
replace asegsoci_b=0.3  if pen044==1 | pen045==1
*Para quien tiene ambos beneficios 
replace asegsoci_b=0.6  if pen044==1 & pen045==1

*Indicadores para cálculo de acceso Seguridad Social y salud *****************
*Por prestacción laboral, jubilación, pensión entre otros

*Generar el identificador de acceso a SS por alguna de las siguientes instituciones
*Que contenga 1 (inscrito como prestación laboral) o 2 (jubilación o invalidez) 
gen p1=0
gen p2=0
gen p3=0

*Por prestación laboral 
replace p1=1   if inst_1=="1" & inscr_1=="1" 
replace p2=1   if inst_2=="2" & inscr_1=="1"
replace p3=1   if inst_3=="3" & inscr_1=="1"

*Por jubilación o invalidez
replace p1=1   if inst_1=="1" & inscr_2=="2"
replace p2=1   if inst_2=="2" & inscr_2=="2"
replace p3=1   if inst_3=="3" & inscr_2=="2"

*Por contratación propia 
replace p1=1 if inst_1=="1" & inscr_6=="6"
replace p2=1 if inst_2=="2" & inscr_6=="6"
replace p3=1 if inst_3=="3" & inscr_6=="6"

* A fin de determinar la cobertura de la SS, se crean variable para identificar 
* a los familiares directos del jefe de familia (pers1) y se aplican las reglas 
* establecidas en las leyes de SS vigentes:
	*Parejas = pers2, hija(o)s=pers3, padres= pers4,  suegros=pers5, nietos=pers6 y nuera o yerno==pers7
	*Dichas variables pers1 a pers5,  toman valor de 1, e identifican al pariente que existe en el hogar
	*Nota: se incluyen parejas del mismo sexo.
destring parentesco, replace
recode parentesco   /// 
       (101 102=1)  ///
	   (200/205=2)  ///
	   (300/305=3)  ///
	   (601=4)      ///
	   (615=5)      ///
	   (609=6)      ///    
	   (617=7)      ///
	   (else=0), ///
	   gen (paren1) 

gen pers1=1 if paren1==1
gen pers2=1 if paren1==2
gen pers3=1 if paren1==3
gen pers4=1 if paren1==4
gen pers5=1 if paren1==5
gen pers6=1 if paren1==6
gen pers7=1 if paren1==7
recode pers1-pers7 (.=0)

* Generar la variable que identifica a la persona con prestación de SS ya sea laboral, por jubilación o invalidez 
*p1 IMSS
*p2 ISSSTE
*p3 ISSSTE ESTATAL

gen persm=p1+ p2 + p3 
label var persm "Persona con prestación de SS laboral/jubilación"

* Generar variable (segsocj) que identifica al jefe del hogar según tipo de institución a la que se tiene acceso.
	* 1 = imss, 2 = issste federal y estatal, 3 = pemex
gen segsocj=0
*IMSS
replace segsocj=1 if  persm>0 & paren1==1 &  inst_1=="1"
*ISSSTE e ISSSTE ESTATAL
replace segsocj=2 if (persm>0 & paren1==1 & (inst_2=="2" | inst_3=="3"))

* Generar variable (segsocc) que identifica a la pareja del jefe del hogar, y el tipo de institución a la que se tiene acceso.
	* 1 = imss, 2 = issste federal y estatal, 3 = pemex
gen segsocc=0
*IMSS
replace segsocc=1 if (persm>0 & paren1==2 &  inst_1=="1") 
*ISSSTE e ISSSTE ESTATAL
replace segsocc=2 if (persm>0 & paren1==2 & (inst_2=="2" | inst_3=="3")) 

* Generar variable (segsoch) que identifica si los hijos del jefe del hogar tienen acceso a SS
gen segsoch=0
*Mayores de 16 con IMSS
replace segsoch=1 if (persm>0 & paren1==3 & inst_1=="1")
*Mayores de 18 con ISSSTE
replace segsoch=2 if (persm>0 & paren1==3 & (inst_2=="2" | inst_3=="3") )

* Generar variable (segsocny) que identifica si la nuera o el yerno del jefe del hogar tienen acceso a SS
gen segsocny=0
*IMSS
replace segsocny=1 if (persm>0 & paren1==7 & inst_1=="1")
*ISSSTE
replace segsocny=2 if (persm>0 & paren1==7 & (inst_2=="2" | inst_3=="3") )

* Generar variable (segsocn) que identifica si el nieto del hogar tienen acceso a SS
gen segsocn=0
*IMSS
replace segsocn=1 if (persm>0 & paren1==6 & inst_1=="1")
*ISSSTE
replace segsocn=2 if (persm>0 & paren1==6 & (inst_2=="2" | inst_3=="3"))

* Generar variable (segsoco) que identifica si algún otro miembro del hogar tienen acceso a SS
gen segsoco=0
*IMSS
replace segsoco=1 if ((persm>0) & (paren1==0 | paren1==4 | paren1==5) & (inst_1=="1"))
*ISSSTE
replace segsoco=2 if ((persm>0) & (paren1==0 | paren1==4 | paren1==5) & (inst_2=="2" | inst_3=="3"))


* Generar variable que identifica si en el hogar hay personas con seguridad social, según parentesco
egen jefe_hogar=  max(segsocj), by (folio) /* jefe del hogar*/
egen conyuge=     max(segsocc), by (folio) /*  conyuge */
egen hijoss=      max(segsoch), by (folio) /*  hijos */
egen NueraYerno=  max(segsocny), by (folio) /*  Nuera o yerno */


egen per1=    max(pers1),   by (folio) /*  jefe de familia */
egen per2=    max(pers2),   by (folio) /*  Parejas */
egen per3=    max(pers3),   by (folio) /*  hija(o)s */
egen per4=    max(pers4),   by (folio) /*  padres */
egen per5=    max(pers5),   by (folio) /*  suegros */
egen per6=    max(pers6),   by (folio) /*  Nietos */
egen per7=    max(pers7),   by (folio) /*  Nuera o Yerno */

******************************************************************************
** 1. Hijo del jefe del hogar que aseguran a los nietos 
******************************************************************************

* Edad del hijo del jefe del hogar
gen edad_hijo = edad if pers3 == 1
recode edad_hijo (.=0)

* Contemplando el mínimo error, nos quedamos con el hijo de mayor edad
egen max_edad_hijo_h = max(edad_hijo) , by(folio)

* Edad de los nietos del jefe del hogar
gen edad_nieto = edad if pers6==1
recode edad_nieto (.=0)

* Identifica al hijo del jefe del hogar con mayor edad y si cuenta con seguridad social IMSS
gen seg_hijo_imss = 1 if segsoch == 1 & (edad == max_edad_hijo_h) 
recode seg_hijo_imss (.=0)
egen seg_hijo_imss_h = max(seg_hijo_imss), by(folio)

* Identifica al hijo del jefe del hogar con mayor edad y cuenta con seguridad social ISSSTE
gen seg_hijo_issste = 2 if segsoch == 2 & (edad == max_edad_hijo_h)
recode seg_hijo_issste (.=0)
egen seg_hijo_issste_h = max(seg_hijo_issste), by(folio)

* Identificamos nietos potenciales
gen nietos_poten = 1 if ( (max_edad_hijo_h - edad_nieto ) >=18 ) & (seg_hijo_imss_h == 1) & (pers6==1)
replace nietos_poten = 2 if ( (max_edad_hijo_h - edad_nieto ) >=18 ) & (seg_hijo_issste_h == 2) & (pers6==1)
recode nietos_poten (.=0)

*Genera una variable que identifica a los nietos del jefe del hogar asegurados que van a la escuela y por lo tanto acceden aa SS por los hijos del jefe del hogar
*Para ISSSTE los menores de 18  o entre 18 y 25 años que asistan a nivel media superior y superior 
gen n_b_issste=.
replace n_b_issste=2 if   edad<=17 & nietos_poten==2 & parentesco == 609
replace n_b_issste=2 if ((edad>=18 & edad<=25) & (asis_esc=="1") & (nivel >="08" & nivel <="12") ) & nietos_poten==2 & parentesco == 609

*Para IMSS, los que son menores a 16 años, o entre 16 y 25 años que asisten a escuela
gen n_b_imss=.
replace n_b_imss=1   if  edad<=15 & nietos_poten==1 &  parentesco == 609
replace n_b_imss=1   if (edad>=16 & edad<=25) & (asis_esc=="1") & (nietos_poten==1) & parentesco == 609
recode n_b_issste n_b_imss (.=0)

******************************************************************************
** 2. Nuera o yerno del jefe del hogar que aseguran a los nietos
******************************************************************************

* Edad de la nuera o yerno 
gen edad_ny = edad if pers7==1
recode edad_ny (.=0)

egen max_edad_ny_h = max(edad_ny), by(folio)

* Sexo de la nuera/yerno de máxima edad en el hogar
destring sexo, replace
gen sex_ny=0
replace sex_ny = sexo if parentesco==617 & edad==max_edad_ny_h
egen sex_ny_h = max(sex_ny), by(folio)

* Sexo del hijo(a) de máxima edad en el hogar
gen sex_h=0
replace sex_h=sexo if parentesco==301 & (edad==max_edad_hijo_h)
egen sex_h_h = max(sex_h), by(folio)

* Identifica a la nuera/yerno de máxima edad que sean de distinto sexo del hijo de máxima edad del jefe del hogar
gen sex_d= (sex_ny_h!=sex_h_h)

* Identifica al nuera o yerno del jefe del hogar con mayor edad y cuenta con seguridad social IMSS
gen seg_ny_imss = 1 if segsocny == 1 & (edad == max_edad_ny_h) 
recode seg_ny_imss (.=0)
egen seg_ny_imss_h = max(seg_ny_imss), by(folio)

* Identifica al nuera o yerno del jefe del hogar con mayor edad y cuenta con seguridad social ISSSTE
gen seg_ny_issste = 2 if segsocny == 2 & (edad == max_edad_ny_h) 
recode seg_ny_issste (.=0)
egen seg_ny_issste_h = max(seg_ny_issste), by(folio)

* Identificamos nietos potenciales
gen nietos_poten_ny = 1 if ( (max_edad_ny_h - edad_nieto ) >=18 ) & (seg_ny_imss_h == 1) & (pers6==1)
replace nietos_poten_ny = 2 if ( (max_edad_ny_h - edad_nieto ) >=18 ) & (seg_ny_issste_h == 2) & (pers6==1)
recode nietos_poten_ny (.=0)

*Genera una variable que identifica a los nietos del jefe del hogar asegurados que van a la escuela y por lo tanto acceden a SS por la nuera o yerno del jefe del hogar
*Para ISSSTE los menores de 18  o entre 18 y 25 años que asistan a nivel media superior y superior 
gen n_b_issste_ny=.
replace n_b_issste_ny=2 if   edad<=17 & nietos_poten_ny==2 & seg_ny_issste_h == 2 & parentesco == 609
replace n_b_issste_ny=2 if ((edad>=18 & edad<=25) & (asis_esc=="1") & (nivel >="08" & nivel <="12") ) & nietos_poten_ny==2 & seg_ny_issste_h == 2 & parentesco == 609

*Para IMSS, los que son menores a 16 años, o entre 16 y 25 años que asisten a escuela
gen n_b_imss_ny=.
replace n_b_imss_ny=1   if  edad<=15 & nietos_poten_ny==1 & seg_ny_imss_h == 1 & parentesco == 609
replace n_b_imss_ny=1   if (edad>=16 & edad<=25) & (asis_esc=="1") & (nietos_poten_ny==1) & seg_ny_imss_h == 1 & parentesco == 609

recode n_b_issste_ny n_b_imss_ny (.=0)

******************************************************************************
*3.Identificamos hijos que pueden ser asegurados por la nuera o el yerno
******************************************************************************

*Contemplando el mínimo error, identificamos a las parejas con diferencia de edad de 5 años
gen hijo_ny=max_edad_ny_h - max_edad_hijo_h 
recode hijo_ny (.=0)

gen hijo_ny_dif=1 if ((hijo_ny>=0 & hijo_ny<=5) | (hijo_ny>=-5 & hijo_ny<=-1))
recode hijo_ny_dif (.=0)

gen hijo_segsoc_ny=1 if hijo_ny_dif==1 & (seg_ny_imss_h == 1) & (pers3==1) & (edad == max_edad_hijo_h) 
replace hijo_segsoc_ny=2 if hijo_ny_dif==1 & (seg_ny_issste_h == 2) & (pers3==1) & (edad == max_edad_hijo_h) 
recode hijo_segsoc_ny (.=0)

******************************************************************************
** 4. Hijos potenciales que cumplen con reglas de parentesco
******************************************************************************

*Genera una variable que identifica a los hijos de asegurados que van a la escuela y por lo tanto acceden aa SS
*Para ISSSTE los menores de 18  o entre 18 y 25 años que asistan a nivel media superior y superior 
gen h_b_issste=.
replace h_b_issste=1 if   edad<=17 & paren1==3 
replace h_b_issste=1 if ((edad>=18 & edad<=25) & (asis_esc=="1") & (nivel >="08" & nivel <="12") ) & paren1==3

*Para IMSS, los que son menores a 16 años, o entre 16 y 25 años que asisten a escuela
gen h_b_imss=.
replace h_b_imss=1   if  edad<=15 & paren1==3
replace h_b_imss=1   if (edad>=16 & edad<=25) & (asis_esc=="1") & (paren1==3)

recode h_b_issste h_b_imss (.=0)

******************************************************************************
** Variable de acceso a seguridad social por IMSS o ISSSTE o ISSTE estatal (asignación)
******************************************************************************

gen asegsoc = 0
replace asegsoc=1 if  segsocj>0 | segsocc>0 | segsoch>0 | segsocny>0 | segsocn>0 | segsoco>0
replace asegsoc=1 if (jefe_hogar==1 & h_b_imss==1) 
replace asegsoc=1 if (jefe_hogar==2 & h_b_issste==1) 
replace asegsoc=1 if (conyuge==1 & h_b_imss==1) 
replace asegsoc=1 if (conyuge==2 & h_b_issste==1) 
replace asegsoc=1 if (jefe_hogar>0 & paren1==4) 
replace asegsoc=1 if (conyuge>0 & paren1==5) 

*Paso 3: Jefe cubre a cónyuge y viceversa
replace asegsoc=1 if (jefe_hogar>0 & (conyuge==0 & paren1==2))
replace asegsoc=1 if (conyuge>0 & (jefe_hogar==0 & paren1==1)) 
*R
*Nuera o Yerno cubre a Hijo del jefe del hogar
replace asegsoc=1 if (hijo_segsoc_ny==1 | hijo_segsoc_ny==2)

*Hijo cubre a Nuera o Yerno
replace asegsoc=1 if (seg_hijo_imss_h==1 | seg_hijo_issste_h==2) & segsocny==0 & sex_d==1 & hijo_ny_dif == 1 & parentesco == 617
*Paso 4: Hijos con prestaciones cubren a  jefe, cónyuge y nietos
replace asegsoc=1 if (hijoss>0 & jefe_hogar==0   & paren1==1) 
replace asegsoc=1 if (hijoss>0 & conyuge==0 & paren1==2) 
*replace asegsoc=1 if (hijoss>0 & segsoch==1)
replace asegsoc=1 if n_b_imss==1 | n_b_issste==2
replace asegsoc=1 if n_b_imss_ny==1 | n_b_issste_ny==2
*R
*replace asegsoc=0 if (hijoss>=1 & segsoch==0 & segsocj==0 & segsocc==0 & (paren1==3 | paren1==0)) 

*Paso 5: Se identifica a las personas que tienen acceso seguridad social de IMSS, ISSSTE e ISSSTE estatal por:
    *inscr_3 = 3 familiar en el hogar
	*inscr_4 = 4 muerte de asegurado
	*inscr_5 = 5 Ser estudiante
    *inscr_7 = 7 Algún familiar de otro hogar
    *inscr_8 = 8 No sabe
replace asegsoc=1 if ((inst_1=="1" | inst_2=="2" | inst_3=="3") & (inscr_3=="3" | inscr_4=="4" |inscr_5=="5"| inscr_7=="7" | inscr_8=="8" ))
*Por contratación propia
replace asegsoc=1 if inscr_6=="6" & asegsoc<1

********************************************************************************
*****************P E M E X******************************************************
********************************************************************************

***4.3 Indicadores para cálculo de acceso Seguridad Social (SS)

*Generar el identificador de acceso a SS por PEMEX
*Que contenga 1 (inscrito como prestación laboral) o 2 (jubilación o invalidez) como su identificador
gen double p4=0

*Por prestación laboral 
replace p4=1 if inst_4=="4" & inscr_1=="1" 
*Por jubilación o invalidez
replace p4=1 if inst_4=="4" & inscr_2=="2"
*Por contratación propia
replace p4=1 if inst_4=="4" & inscr_6=="6"

* Generar la variable que identifica a la persona con prestación de SS ya sea laboral, por jubilación o invalidez 
*P4 PEMEX, la defensa o la Marina 
label var p4 "Persona con prestación de SS laboral/jubilación PEMEX"

* Generar variable (segsocj) que identifica al jefe del hogar según tipo de institución a la que se tiene acceso= pemex
gen segsocj_pemex=0
*PEMEX, la defensa o la Marina
replace segsocj_pemex=1 if  p4==1 & paren1==1 &  inst_4=="4"

* Generar variable (segsocc) que identifica a la pareja del jefe del hogar, y el tipo de institución a la que se tiene acceso = pemex
gen segsocc_pemex=0
*PEMEX, la defensa o la Marina
replace segsocc_pemex=1 if (p4==1 & paren1==2 &  inst_4=="4")

* Generar variable (segsoch) que identifica si los hijos del jefe del hogar tienen acceso a SS
*Mayores de 18 p
gen segsoch_pemex=0
*Mayores de 18 con PEMEX, la defensa o la Marina
replace segsoch_pemex=1 if (p4==1 & paren1==3 &  inst_4=="4")

* Generar variable (segsocny) que identifica si la nuera o el yerno del jefe del hogar tienen acceso a SS
gen segsocny_pemex=0
replace segsocny_pemex=1 if (p4==1) & paren1==7 & (inst_4=="4" ) 

* Generar variable (segsocn_pemex) que identifica si el nieto o nieta del jefe del hogar tienen acceso a SS
gen segsocn_pemex=0
replace segsocn_pemex=1 if (p4==1) & paren1==6 & (inst_4=="4" ) 

* Generar variable (segsoco_pemex) que identifica si el nieto o nieta del jefe del hogar tienen acceso a SS
gen segsoco_pemex=0
replace segsoco_pemex=1 if (p4==1) & (paren1==0 | paren1==4 | paren1==5) & (inst_4=="4" ) 

* Generar variable que identifica si en el hogar hay personas con seguridad social, según parentesco
egen double jefe_pemex    =  max(segsocj_pemex), by (folio) /* jefe del hogar*/
egen double conyuge_pemex =  max(segsocc_pemex), by (folio) /*  conyuge */
egen double hijoss_pemex  =  max(segsoch_pemex), by (folio) /*  hijos */
egen double NueraYerno_pemex=max(segsocny_pemex), by (folio) /*  Nuera o yerno */

******************************************************************************
** X. Hijo del jefe del hogar que aseguran a los nietos por PEMEX
******************************************************************************

* Identifica al hijo del jefe del hogar con mayor edad y si cuenta con seguridad social PEMEX
gen seg_hijo_pemex = 1 if segsoch_pemex == 1 & (edad == max_edad_hijo_h) 
recode seg_hijo_pemex (.=0)
egen seg_hijo_pemex_h = max(seg_hijo_pemex), by(folio)

* Identificamos nietos potenciales
gen nietos_poten_pemex = 1 if ( (max_edad_hijo_h - edad_nieto ) >=18 ) & (seg_hijo_pemex_h == 1) & (pers6==1)
recode nietos_poten_pemex (.=0)

*Para PEMEX, la defensa o la Marina, los hijos menores de 18 o entre 18 y 25 años que asistan a la escuela
gen n_b_pemex=.
replace n_b_pemex=1 if   edad<=17 & nietos_poten_pemex==1 &  parentesco == 609
replace n_b_pemex=1 if  (edad>=18 & edad<=25) & (asis_esc=="1") & nietos_poten_pemex==1 &  parentesco == 609
recode n_b_pemex (.=0)

******************************************************************************
** X. Nuera o yerno del jefe del hogar que aseguran a los nietos PEMEX
******************************************************************************

* Identifica al nuera o yerno del jefe del hogar con mayor edad y cuenta con seguridad social IMSS
gen seg_ny_pemex = 1 if segsocny_pemex == 1 & (edad == max_edad_ny_h) 
recode seg_ny_pemex (.=0)
egen seg_ny_pemex_h = max(seg_ny_pemex), by(folio)

* Identificamos nietos potenciales
gen nietos_poten_ny_pemex = 1 if ( (max_edad_ny_h - edad_nieto ) >=18 ) & (seg_ny_pemex_h == 1) & (pers6==1)
recode nietos_poten_ny_pemex (.=0)

*Para PEMEX, la defensa o la Marina, los hijos menores de 18 o entre 18 y 25 años que asistan a la escuela
gen n_b_pemex_ny=.
replace n_b_pemex_ny=1 if   edad<=17 & nietos_poten_ny_pemex==1 &  parentesco == 609
replace n_b_pemex_ny=1 if  (edad>=18 & edad<=25) & (asis_esc=="1") & nietos_poten_ny_pemex==1 &  parentesco == 609
recode  n_b_pemex_ny (.=0)

recode n_b_pemex_ny (.=0)

******************************************************************************
*x.Identificamos hijos que pueden ser asegurados por la nuera o el yerno por PEMEX
******************************************************************************

gen hijo_segsoc_pemex_ny=1 if hijo_ny_dif==1 & (seg_ny_pemex_h == 1) & (pers3==1) & (edad == max_edad_hijo_h) 
recode hijo_segsoc_pemex_ny (.=0)

******************************************************************************
** X. Hijos potenciales que cumplen con reglas de parentesco
******************************************************************************

*Para PEMEX, la defensa o la Marina, los hijos menores de 18 o entre 18 y 25 años que asistan a la escuela
gen h_b_pemex=.
replace h_b_pemex=1 if   edad<=17 & paren1==3 
replace h_b_pemex=1 if  (edad>=18 & edad<=25) & (asis_esc=="1") & paren1==3

recode h_b_pemex (.=0)

******************************************************************************
** Variable de acceso a seguridad social por PEMEX (asignación)
******************************************************************************

*Generar una variable de Acceso a seguridad social PEMEX
gen asegsoci_pemex=0 

*Paso 2: Se reemplaza de acuerdo a ser asegurado o recibirlo por medio de la pareja, padre/madre o hijas/hijos
*Personas con acceso a SS o jubilacion
*segsocj jefe del hogar
*segsocc conyuge 
*segsoch hijo 

replace asegsoci_pemex=1 if  segsocj_pemex==1 | segsocc_pemex==1 | segsoch_pemex==1 | segsocny_pemex == 1 | segsocn_pemex==1 | segsoco_pemex==1
replace asegsoci_pemex=1 if (jefe_pemex==1   & h_b_pemex==1)
replace asegsoci_pemex=1 if (conyuge_pemex==1 & h_b_pemex==1)
replace asegsoci_pemex=1 if (jefe_pemex==1   & paren1==4) 
replace asegsoci_pemex=1 if (conyuge_pemex==1 & paren1==5) 

*Paso 3: Jefe cubre a cónyuge y viceversa.
replace asegsoci_pemex=1 if jefe_pemex==1    & conyuge_pemex==0 & paren1==2
replace asegsoci_pemex=1 if (conyuge_pemex==1 & (jefe_pemex==0   & paren1==1)) 

*Nuera o Yerno cubre a Hijo del jefe del hogar
replace asegsoci_pemex=1 if hijo_segsoc_pemex_ny==1 
*Hijo cubre a Nuera o Yerno
replace asegsoc=1 if seg_hijo_pemex_h==1 & segsocny_pemex==0 & sex_d==1 & hijo_ny_dif == 1 & parentesco == 617

*Paso 4: Hijos con prestaciones cubren a  jefe y cónyuge.
replace asegsoci_pemex=1 if (hijoss_pemex==1 & jefe_pemex==0    & paren1==1) 
replace asegsoci_pemex=1 if (hijoss_pemex==1 & conyuge_pemex==0 & paren1==2) 
replace asegsoci_pemex=1 if n_b_pemex==1 


*replace asegsoci_pemex=0 if (hijoss==1 & segsoch_pemex==0 & segsocj_pemex==0 & segsocc_pemex==0 & (paren1==3 | paren1==0)) | n_b_pemex==1 


*Paso 5: Se identifica a las personas que tienen acceso indirecto a SS de PEMEX
	*inscr_3 = 3 familiar en el hogar
	*inscr_4 = 4 muerte de asegurado
	*inscr_5 = 5 Ser estudiante
    *inscr_7 = 7 Algún familiar de otro hogar
    *inscr_8 = 8 No sabe
replace asegsoci_pemex=1 if ((inst_4=="4") & (inscr_3=="3" | inscr_4=="4" | inscr_5=="5" | inscr_7=="7" | inscr_8=="8" ))

*Para todas aquellas personas con acceso a PEMEX su valor se reemplaza por 1.2
gen segsocial= .
replace segsocial = asegsoci_b /* programa social */
replace segsocial = 1 if asegsoc_jub==1 /* jubilación */
replace segsocial = 1 if asegsoc==1 /* IMSS ISSSTE o ISSTE ESTATAL */
replace segsocial = 1.2 if asegsoci_pemex==1 /* PEMEX */


*Etiquetar variables
label var segsocial "Acceso a seguridad social, individuo"

save "$tmp/seguridadsocialdh.dta", replace

********************************************************************************
*5.2 Acceso a la salud 
*******************************************************************************
*Generar la base de población para unirse a la anterior de pensiones
use "$tmp/seguridadsocialdh.dta", clear

*Generar variable de acceso a salud por programas sociales 
gen salud=0
*0.33 si tiene "otro"
*Se reemplaza el Acceso a Salud, con los siguientes valores
replace salud=0.33 if inst_6=="6"
*identifica aquellas personas que tienen acceso a salud "seguro popular" o "IMSS Prospera/IMSS-Bienestar"
replace salud=0.51 if segpop=="1" | inst_5=="5"

*Identificar a los que tienen acceso a la salud por seguridad social, de IMSS, ISSSTE e ISSSTE estatal
replace salud=1 if asegsoc==1

*Identificar a los que tienen acceso a la salud por seguridad social, PEMEX
replace salud=1.2 if asegsoci_pemex==1

*Identificar aquellas personas que tienen acceso a "seguro privado"
replace salud=1.5 if segvol_2=="2"

keep folio numren salud segsocial

save "$tmp/saludhysegsocial.dta", replace

********************************************************************************
********************************************************************************

*Generar la base de población para unirse a la anterior de pensiones
use "$bases/poblacion.dta", clear

*Se genera la variable folio
egen folio= concat(folioviv foliohog)
sort folio numren 

*Se eliminan los que no son miembros de la familia en el hogar
destring parentesco, replace
drop if parentesco>=400 & parentesco <500
drop if parentesco>=700 & parentesco <800

merge m:1 folio numren using "$tmp/saludhysegsocial.dta"
drop _merge
*Se une con la base de ingresos
merge m:1 folio using "$tmp/cict.dta"
drop _merge

*Se une con la base de prelación
merge 1:1 folio numren using "$tmp/prelacion.dta"
drop _merge 

rename prelacion prelacion2

gen remanente = yctradj-LP_N
replace remanente =0 if remanente<0

gen pot_pag = 1 if remanente >0
recode pot_pag(.=0)

gen med_pri=.
replace med_pri=1 if yctradj>(LP_N)
recode med_pri (.=0)

gen costoSMP_i=.
replace costoSMP_i= 1571 if edad>= 0 & edad<=19 & sexo=="1"
replace costoSMP_i= 1571 if edad>= 0 & edad<=19 & sexo=="2"
replace costoSMP_i= 2085 if edad>=20 & edad<=29 & sexo=="1"
replace costoSMP_i= 2727 if edad>=20 & edad<=29 & sexo=="2"
replace costoSMP_i= 2699 if edad>=30 & edad<=39 & sexo=="1"
replace costoSMP_i= 3690 if edad>=30 & edad<=39 & sexo=="2"
replace costoSMP_i= 3943 if edad>=40 & edad<=49 & sexo=="1"
replace costoSMP_i= 5130 if edad>=40 & edad<=49 & sexo=="2"
replace costoSMP_i= 6550 if edad>=50 & edad<=59 & sexo=="1"
replace costoSMP_i= 7450 if edad>=50 & edad<=59 & sexo=="2"
replace costoSMP_i=11963 if edad>=60 & edad<=69 & sexo=="1"
replace costoSMP_i=11963 if edad>=60 & edad<=69 & sexo=="2"
replace costoSMP_i=23530 if edad>=70 & edad<=79 & sexo=="1"
replace costoSMP_i=23530 if edad>=70 & edad<=79 & sexo=="2"
replace costoSMP_i=41936 if edad>=80 & sexo=="1"
replace costoSMP_i=41936 if edad>=80 & sexo=="2"
label var costoSMP_i "costo del seguro medico privado"

recode costoSMP_i pot_pag (.=0)
replace costoSMP_i = 0 if salud == 1.5

egen SMP_h = sum(costoSMP_i), by (folio)

*******************************************************************************
*Se asigna el costo de pagar el seguro privado para obtener una renta vitalicia a los 65 años (SSP) 
*por rangos de edad
*******************************************************************************

gen ren_vit=.
replace ren_vit=1 if yctradj>LP_N
recode ren_vit (.=0)

gen renta_vit_i=.
replace  renta_vit_i= 970 if edad>=14 & edad<=24
replace  renta_vit_i=1337 if edad>=25 & edad<=34
replace  renta_vit_i=2160 if edad>=35 & edad<=44
replace  renta_vit_i=4080 if edad>=45 & edad<=50
recode renta_vit_i (.=0)

*Costo de renta vitalicia
egen RV_i = min(renta_vit_i) if renta_vit_i>0, by (folio)
recode RV_i (.=0)

egen RV_h = max(RV_i), by (folio)
recode RV_h (.=0)
gen costo_SMP_RV_h= SMP_h + RV_h if SMP_h>0 & RV_h >0
gen pago_SMP_RV_h = 1 if remanente>costo_SMP_RV_h
recode pago_SMP_RV_h(.=0)
recode costo_SMP_RV_h (.=0)

gen ded_salud_ss_priv=.
replace ded_salud_ss_priv= costo_SMP_RV_h if pago_SMP_RV_h==1
recode ded_salud_ss_priv (.=0)

*Hogares que declararon tener seguro de gastos médicos mayores para todos sus miembros 
* y que pueden pagar renta vitalicia  
gen seg_gast_med = salud/1.5
egen salud_priv_sum = sum(seg_gast_med), by (folio)
gen con_salud_priv_h = salud_priv_sum/tam_hog

gen pot_pago_RV_h_salud_priv_h= 1 if con_salud_priv_h ==1 & (remanente>RV_h) & RV_h>0
recode pot_pago_RV_h_salud_priv_h (.=0)

gen costo_RV_h_salud_priv_h = RV_h if pot_pago_RV_h_salud_priv_h==1 
recode costo_RV_h_salud_priv_h(.=0)

replace ded_salud_ss_priv= costo_RV_h_salud_priv_h if costo_RV_h_salud_priv_h>0


gen Y_segsocial =.
gen Y_salud =.
replace Y_segsocial=1.5 if costo_SMP_RV_h>0 & pago_SMP_RV_h==1
replace Y_salud=1.5 if costo_SMP_RV_h>0 & pago_SMP_RV_h==1

replace Y_segsocial=1.5 if (costo_SMP_RV_h>0 | costo_RV_h_salud_priv_h >0) & pot_pago_RV_h_salud_priv_h==1
recode Y_salud Y_segsocial (.=0)

gen rem_sup_sal_ss_priv = 1 if remanente>ded_salud_ss_priv

****************************************
****************************************
*Paso 2. Para los hogares que no pueden pagar la RV (ya sea por ingreso bajo o porque ninguno de sus miembros tiene entre 14 y 50 años) se verifica si pueden pagar además del SMP para todos sus miembros, el SVO para todos sus miembros no cubiertos por la Seguridad social pública.
****************************************
****************************************

*generar una variable que identifique el gasto del SVO
gen SVO=1198.60

**************************
**cambién condicional de relación ingreso LP_N por remanente
***************************

*se genera variable que identifica a las personas y hogares sin seguridad social normativa

gen sin_segsoc_i = 1 if Y_segsocial ==0 & segsocial <1 & salud<1.5 & remanente >0
recode sin_segsoc_i (.=0)
egen sin_segsoc_h = max (sin_segsoc_i), by (folio)

gen pot_pago_SMP_h_SVO= 1 if remanente >0 & sin_segsoc_i==1
recode pot_pago_SMP_h_SVO (.=0)

destring parentesco, replace
recode parentesco   /// 
       (101 102=1)  ///
	   (200/205=2)  ///
	   (300/305=3)  ///
	   (601=4)      ///
	   (615=5)      ///
	   (609=6)      ///    
	   (617=7)      ///
	   (else=0), ///
	   gen (paren1)
	   
gen pers1=1 if paren1==1
gen pers2=1 if paren1==2
gen pers3=1 if paren1==3
gen pers4=1 if paren1==4
gen pers5=1 if paren1==5
gen pers6=1 if paren1==6
gen pers7=1 if paren1==7
recode pers1-pers7 (.=0)

*Se identifica a los hogares que pueden pagar SMP para todo el hogar y el costo de un SVO
gen segsocial_h=.
replace segsocial_h=1 if pot_pago_SMP_h_SVO==1
recode  segsocial_h (.=0)

*Seguro potencial-jefe del hogar sin segsocial
gen segsocj_pot=.
replace segsocj_pot=1 if segsocial_h==1 & paren1==1 & sin_segsoc_i == 1 
recode  segsocj_pot (.=0)

*Seguro potencial-conyuge  sin segsocial
gen segsocc_pot=.
replace segsocc_pot=1 if segsocial_h==1 & paren1==2 & sin_segsoc_i==1
recode  segsocc_pot (.=0)

*Seguro potencial para hijos sin segsocial
gen segsoch_pot=.
replace segsoch_pot=1 if segsocial_h==1 & paren1==3 & sin_segsoc_i == 1 & edad>=15
recode segsoch_pot (.=0)

*Seguro potencial para nuera o yerno sin segsocial
gen segsocny_pot=.
replace segsocny_pot=1 if segsocial_h==1 & paren1==7 & sin_segsoc_i==1 
recode segsocny_pot (.=0)

*Seguro potencial para nietos sin segsocial
gen segsocn_pot=.
replace segsocn_pot=1 if segsocial_h==1 & paren1==6 & sin_segsoc_i == 1 & edad>=15
recode  segsocn_pot (.=0)

*Seguro potencial para padres sin segsocial
gen segsocpad_pot=.
replace segsocpad_pot=1 if segsocial_h==1 & paren1==4 & sin_segsoc_i == 1 
recode  segsocpad_pot (.=0)

*Seguro potencial para suegros sin segsocial
gen segsocsueg_pot=.
replace segsocsueg_pot=1 if segsocial_h==1 & paren1==5 & sin_segsoc_i == 1 
recode  segsocsueg_pot (.=0)

*Seguro potencial para algún otro miembro del hogar sin segsocial
gen segsoco_pot=.
replace segsoco_pot=1 if (segsocial_h==1) & (paren1==0) & (sin_segsoc_i == 1) 
recode segsoco_pot (.=0)

******************************************************************************
** X. Hijo del jefe del hogar que aseguran a los nietos 
******************************************************************************

* Edad del hijo del jefe del hogar
gen edad_hijo_svo = edad if pers3 == 1
recode edad_hijo_svo (.=0)

* Contemplando el mínimo error, nos quedamos con el hijo de mayor edad
egen max_edad_hijo_svo_h = max(edad_hijo_svo) , by(folio)

* Edad de los nietos del jefe del hogar
gen edad_nieto_svo = edad if pers6==1
recode edad_nieto_svo (.=0)

* Identifica al hijo del jefe del hogar con mayor edad y puede pagar el SVO
gen seg_hijo_svo = 1 if segsoch_pot == 1 & (edad == max_edad_hijo_svo_h) 
recode seg_hijo_svo (.=0)
egen seg_hijo_svo_h = max(seg_hijo_svo), by(folio)

* Identificamos nietos potenciales
gen nietos_svo_poten = 1 if ( (max_edad_hijo_svo_h - edad_hijo_svo ) >=18 ) & (seg_hijo_svo_h == 1) & (pers6==1)
recode nietos_svo_poten (.=0)

*Para SVO, los que son menores a 16 años, o entre 16 y 25 años que asisten a escuela
gen n_b_svo=.
replace n_b_svo=1   if  edad<=15 & nietos_svo_poten==1 &  parentesco == 609
replace n_b_svo=1   if ((edad>=16 & edad<=25) & (asis_esc=="1")) & (nietos_svo_poten==1) & parentesco == 609
recode  n_b_svo (.=0)

******************************************************************************
** x. Nuera o yerno del jefe del hogar que aseguran a los nietos
******************************************************************************

* Edad de la nuera o yerno 
gen edad_ny_svo = edad if pers7==1
recode edad_ny_svo (.=0)

egen max_edad_ny_svo_h = max(edad_ny_svo), by(folio)

* Sexo de la nuera/yerno de máxima edad en el hogar
destring sexo, replace
gen sex_svo_ny=0
replace sex_svo_ny = sexo if parentesco==617 & edad==max_edad_ny_svo_h

egen sex_ny_svo_h = max(sex_svo_ny), by(folio)

* Sexo del hijo(a) de máxima edad en el hogar
gen sex_svo_h=0
replace sex_svo_h=sexo if parentesco==301 & (edad==max_edad_hijo_svo_h)
egen sex_svo_h_h = max(sex_svo_h), by(folio)

* Identifica a la nuera/yerno de máxima edad que sean de distinto sexo del hijo de máxima edad del jefe del hogar
gen sex_svo_d= (sex_ny_svo_h!=sex_svo_h_h)

* Identifica al nuera o yerno del jefe del hogar con mayor edad y cuenta con seguridad social SVO
gen seg_ny_svo = 1 if segsocny_pot == 1 & (edad == max_edad_ny_svo_h) 
recode seg_ny_svo (.=0)
egen seg_ny_svo_h = max(seg_ny_svo), by(folio)

* Identificamos nietos potenciales
gen nietos_poten_svo_ny = 1 if ( (max_edad_ny_svo_h - edad_nieto ) >=18 ) & (seg_ny_svo_h == 1) & (pers6==1)
recode nietos_poten_svo_ny (.=0)


*Para SVO, los que son menores a 16 años, o entre 16 y 25 años que asisten a escuela
gen n_b_svo_ny=.
replace n_b_svo_ny=1   if  edad<=15 & nietos_poten_svo_ny==1 & seg_ny_svo_h == 1 & parentesco == 609
replace n_b_svo_ny=1   if (edad>=16 & edad<=25) & (asis_esc=="1") & (nietos_poten_svo_ny==1) & seg_ny_svo_h == 1 & parentesco == 609

recode n_b_svo_ny (.=0)

******************************************************************************
*X.Identificamos hijos que pueden ser asegurados por la nuera o el yerno
******************************************************************************

*Contemplando el mínimo error, identificamos a las parejas con diferencia de edad de 5 años
gen hijo_svo_ny=max_edad_ny_svo_h - max_edad_hijo_svo_h 
recode hijo_svo_ny (.=0)

gen hijo_ny_svo_dif=1 if ((hijo_svo_ny>=0 & hijo_svo_ny<=5) | (hijo_svo_ny>=-5 & hijo_svo_ny<=-1))
recode hijo_ny_svo_dif (.=0)

gen hijo_segsoc_svo_ny=1 if hijo_ny_svo_dif==1 & (seg_ny_svo_h == 1) & (pers3==1) & (edad == max_edad_hijo_svo_h) 
recode hijo_segsoc_svo_ny (.=0)

******************************************************************************
** X. Hijos potenciales que cumplen con reglas de parentesco
******************************************************************************

*Para IMSS, los que son menores a 16 años, o entre 16 y 25 años que asisten a escuela
gen h_b_svo=.
replace h_b_svo=1   if  edad<=15 & paren1==3
replace h_b_svo=1   if (edad>=16 & edad<=25) & (asis_esc=="1") & (paren1==3)

recode h_b_svo (.=0)

******************************************************************************
** Variable de acceso a seguridad social por SVO (asignación)
******************************************************************************

egen jefe_pot   = max(segsocj_pot), by (folio) /* jefe del hogar pot seg soc */
egen conyuge_pot= max(segsocc_pot), by (folio) /*  conyuge pot seg soc */
egen hijoss_pot = max(segsoch_pot), by (folio) /*  hijos pot seg soc */
egen nuera_pot = max(segsocny_pot), by (folio) /*  Nuera o Yerno */
egen nieto_pot = max(segsocn_pot), by (folio) /*  nietos */
egen padres_pot= max(segsocpad_pot), by(folio) /*  padres */
egen suegros_pot=max(segsocsueg_pot), by(folio) /*  suegros */
egen otros_pot = max(segsoco_pot), by (folio) /*  otros */
 

*Jefe cubre a cónyuge y así mismo
gen pago_SVO_jef =.
replace pago_SVO_jef =1 if jefe_pot==1 & paren1==1 & segsocj_pot==1 
replace pago_SVO_jef =1 if jefe_pot==1 & paren1==2 & segsocc_pot==1
replace pago_SVO_jef =1 if jefe_pot==1 & paren1==3 & h_b_svo==1
replace pago_SVO_jef =1 if jefe_pot==1 & paren1==4 
recode pago_SVO_jef (.=0)
egen SVO_j = max(pago_SVO_jef), by (folio)


*Cónyuge se cubre sola
gen     pago_SVO_c =.
replace pago_SVO_c =1 if conyuge_pot==1 & paren1==2 & SVO_j==0
replace pago_SVO_c =1 if conyuge_pot==1 & paren1==5 & SVO_j==0
replace pago_SVO_c =1 if conyuge_pot==1 & paren1==3 & h_b_svo==1 & SVO_j==0
recode  pago_SVO_c (.=0)
egen SVO_c = max(pago_SVO_c), by (folio)

*Hijos que cubren a jefe y cónyuge y nietos.
gen  pago_SVO_h  =.
replace pago_SVO_h  =1 if hijoss_pot==1 & paren1==3 & SVO_j==0 & SVO_c ==0
replace pago_SVO_h  =1 if hijoss_pot==1 & paren1==2 & SVO_j==0 & SVO_c ==0
replace pago_SVO_h  =1 if hijoss_pot==1 & paren1==1 & SVO_j==0 & SVO_c ==0
replace pago_SVO_h  =1 if hijoss_pot==1 & paren1==7 & sex_svo_d==1 & hijo_ny_svo_dif == 1 
replace pago_SVO_h  =1 if hijoss_pot==1 & paren1==6 & n_b_svo==1  
recode pago_SVO_h (.=0)
egen SVO_h = max(pago_SVO_h), by (folio)

**Nuera que cubren al hijo, nietos y así mismo. 
gen  pago_SVO_nuera  =.
replace pago_SVO_nuera  =1 if nuera_pot==1 & paren1==7 & SVO_h==0 
replace pago_SVO_nuera  =1 if nuera_pot==1 & paren1==3 & SVO_j==0 & SVO_c==0 & SVO_h==0 & sex_svo_d==1 & hijo_ny_svo_dif==1 
replace pago_SVO_nuera  =1 if nuera_pot==1 & paren1==6 & n_b_svo==1 & SVO_h==0
recode pago_SVO_nuera (.=0)
egen SVO_nuera = max(pago_SVO_nuera), by (folio)

***Nieto que se cubre así mismo
gen pago_SVO_nieto=.
replace pago_SVO_nieto=1 if nieto_pot==1 & paren1==6 & sin_segsoc_i == 1 & SVO_h==0 & SVO_nuera==0
recode pago_SVO_nieto (.=0)
egen SVO_nieto= sum(pago_SVO_nieto), by (folio)

*Cobertura de miembros con otros parentescos
*padres del jefe del hogar se aseguran asi mismos
gen pago_SVO_padres=.
replace pago_SVO_padres=1 if padres_pot==1 & paren1==4 & sin_segsoc_i == 1 & SVO_j==0
egen SVO_padres=sum(pago_SVO_padres), by(folio)

*suegros del jefe del hogar se aseguran asi mismos
gen pago_SVO_suegros=.
replace pago_SVO_suegros=1 if suegros_pot==1 & paren1==5 & sin_segsoc_i == 1 & SVO_c==0
egen SVO_suegros=sum (pago_SVO_suegros), by(folio)

*Otros nuera o yerno
gen pago_SVO_op_ny =.
replace pago_SVO_op_ny=1 if nuera_pot==1 & paren1==7 & sex_svo_d==0 & hijo_ny_svo_dif==0 & sin_segsoc_i == 1
egen SVO__op_ny=sum (pago_SVO_op_ny), by(folio)

*otros parentescos 
gen pago_SVO_op=.
replace pago_SVO_op=1 if otros_pot==1 & (paren1==0) & sin_segsoc_i == 1
recode pago_SVO_op (.=0)
egen SVO_op= sum(pago_SVO_op), by (folio)

recode pago_SVO_op_ny pago_SVO_suegros (.=0)

*******************************************************************************
gen costo_SVO_hj = (SVO_j + SVO_c +SVO_h+SVO_nuera+SVO_nieto+SVO_padres+SVO_suegros+SVO__op_ny+SVO_op)* SVO

gen pago_SMP_h_SVO_h= SMP_h+costo_SVO_hj if SMP_h>0 & costo_SVO_hj>0 & remanente> (SMP_h+costo_SVO_hj) & ded_salud_ss_priv==0
recode pago_SMP_h_SVO_h (.=0)

replace Y_salud = 1.5 if pago_SMP_h_SVO_h >0
replace Y_segsocial = 1 if pago_SMP_h_SVO_h >0 & segsocial <1

replace ded_salud_ss_priv= pago_SMP_h_SVO_h if pago_SMP_h_SVO_h >0

********************************************************************************
*Paso 3. Se verifica si el hogar puede pagar el total de SVO requeridos para cubrir 
*a todos sus miembros en el hogar (sin incluir SMP).
********************************************************************************

gen pot_pag_SVO_h = 1 if  (remanente > costo_SVO_hj) & ded_salud_ss_priv==0 & costo_SVO_h>0
recode pot_pag_SVO_h (.=0)

replace Y_salud = 1 if pot_pag_SVO_h==1 & Y_salud ==0 & salud<1
replace Y_segsocial = 1 if pot_pag_SVO_h==1 & Y_segsocial ==0 & segsocial <1

replace ded_salud_ss_priv= costo_SVO_hj if pot_pag_SVO_h == 1

*******************************************************************************************************
*Paso 4. Para hogares que sí pueden pagar el SVO para todos sus miembros que lo necesitan, 
*pero no pueden pagar todo el SMP_h se calcula su posibilidd de pagar el SMP_i por orden de preelación.
*******************************************************************************************************
*El orden de prioridad es el siguiente: 
*1) el principal sostén de la familia;
*2) en H con niños menores de 12 años, la madre o persona que cuida a los menores; 
*3) adolescentes de 14 a 17 años; 
*4) menores de 0 a 13
*5) mayore (de 18 en adelante) de menor a mayor.
*******************************************************************************************************

*Identifica a la población potencial para el pago del SMPi ** se suma el costo más bajo del SMP_i
gen pot_pago_SMPij_SVOh = 1 if remanente> (costo_SVO_hj+2248) & costo_SVO_hj>0
recode pot_pago_SMPij_SVOh (.=0)


tostring prelacion2, replace 
sort folio prelacion2 numren
bysort folio: gen SMP_ij= sum(costoSMP_i) if pot_pago_SMPij_SVOh==1
recode SMP_ij(.=0)

*Se identifica las personas que se pueden cubrir con SMPi y SVOh
gen double relacion1=(yctradj/(LP_N+ SMP_ij + costo_SVO_hj)) if pot_pago_SMPij_SVOh==1
recode relacion1 (.=0)

*Identificael pago que se puede hacer para las personas con SMPi
gen pago_SMP_i=costoSMP_i if relacion1>=1 & remanente>0 
recode pago_SMP_i (.=0)

*Pago por hogar del SMPi
egen  costo_SMP_ij=sum(pago_SMP_i), by (folio)
recode costo_SMP_ij (.=0)

*Pago por hogar del SMPi y el SVOh
gen costo_SMP_ij_SVO_h = costo_SMP_ij + costo_SVO_hj if costo_SMP_ij>0 & costo_SVO_hj
recode costo_SMP_ij_SVO_h (.=0)

gen pot_pago_costo_SMP_ij_SVO_h = 1 if (remanente > costo_SMP_ij_SVO_h) & costo_SMP_ij >0
recode pot_pago_costo_SMP_ij_SVO_h (.=0)

*Hogares que pueden cubirir ambos costos
gen pago_SMPij_SVOh = costo_SMP_ij_SVO_h if pot_pago_costo_SMP_ij_SVO_h == 1 
recode pago_SMPij_SVOh (.=0)

*Se remplaza con 1.5 en salud a quienes pueden pagar el SMPi
replace Y_salud = 1.5 if pago_SMP_i>0 & pago_SMPij_SVOh >0
replace Y_salud = 1 if pago_SMP_i==0 & pago_SMPij_SVOh >0
*Se remplaza con 1 en seguridad social a quienes pueden pagar el SVO
replace Y_segsocial = 1 if pago_SMPij_SVOh >0 & Y_segsocial <1 & segsocial <1 

*Total a deducir del ingreso por el SMPi y el SVOh
replace ded_salud_ss_priv=pago_SMPij_SVOh if remanente >(costo_SMP_ij + costo_SVO_hj) & RV_h==0

sort folio numren

********************************************************************************
*Paso 5. para los que no pueden pagar el SVO para todos los miembros del hogar que lo requieran
*primero  se cubre al mayor número de personas posibles con SFV
********************************************************************************

gen SFV_potj=1 if remanente > 0 & salud < 1 & Y_salud < 1
recode SFV_potj(.=0)

gen costo_SVFi=.
replace costo_SVFi=(3250)/12  if edad>=0  & edad<=19 & SFV_potj==1
replace costo_SVFi=(3850)/12  if edad>=20 & edad<=29 & SFV_potj==1
replace costo_SVFi=(4100)/12  if edad>=30 & edad<=39 & SFV_potj==1
replace costo_SVFi=(5700)/12  if edad>=40 & edad<=49 & SFV_potj==1
replace costo_SVFi=(6000)/12  if edad>=50 & edad<=59 & SFV_potj==1
replace costo_SVFi=(8700)/12  if edad>=60 & edad<=69 & SFV_potj==1
replace costo_SVFi=(9050)/12  if edad>=70 & edad<=79 & SFV_potj==1
replace costo_SVFi=(9100)/12  if edad>=80 & SFV_potj==1

label var costo_SVFi "Cuota IMSS régimen voluntario mensual por persona"
recode costo_SVFi (.=0)

*Se crea una variable que sume el total del costo de cubrir a todo el hogar de SVF.
egen SVF_h = sum(costo_SVFi), by (folio)

gen pago_SVF_h = SVF_h if (remanente > SVF_h) & ded_salud_ss_priv==0
recode  pago_SVF_h (.=0)
gen pot_pag_SVF_i = 1 if pago_SVF_h>0 & salud<1
recode pot_pag_SVF_i (.=0)
egen pot_pag_SVF_h = max(pot_pag_SVF_i), by (folio)

replace Y_salud = 1 if pago_SVF_h > 0 & Y_salud ==0 & salud<1 
replace ded_salud_ss_priv=SVF_h if pot_pag_SVF_h == 1 & ded_salud_ss_priv==0

********************************************************************************
*Paso 6. Para los hogares que no pueden pagar el SVF para todos sus miembros, ni tampoco el SVO, 
* se raliza una comprobación orden de prelación según tipo de principal proveedor del hogar y por grupos de edad
*********************************************************************************

*Remanente de ingresos para los que pueden pagar el SVF individual  
gen pot_pago_SVF_ij= 1 if remanente>390 & ded_salud_ss_priv==0
recode pot_pago_SVF_ij (.=0)

*Costo de SVFi
gen costo_SVFi2 = costo_SVFi if remanente>=costo_SVFi & pot_pago_SVF_ij==1 & Y_salud==0 & salud<1
recode costo_SVFi2 (.=0)

sort folio numren prelacion2
bysort folio: gen SVF_ij=sum(costo_SVFi2)
gen double relacion2=(yctradj/(LP_N+ SVF_ij)) if SVF_ij>0
recode relacion2 (.=0)

****************************************************************
*Se identifica al hogar que puede costear el SVF para algunos de sus miembros
gen pago_SVFi= costo_SVFi2 if relacion2>=1 & costo_SVFi2>0
recode pago_SVFi (.=0)

egen costo_SVFi_h=sum(pago_SVFi), by (folio)
gen pago_SVFi_h = 1 if yctradj >= (LP_N+ costo_SVFi_h) & costo_SVFi_h>0 
recode pago_SVFi_h (.=0)

replace Y_salud = 1 if pago_SVFi >0 & salud<1 & Y_salud <1
replace ded_salud_ss_priv = costo_SVFi_h if pago_SVFi_h ==1 & ded_salud_ss_priv==0

****
gen asegsoci_1= max(segsocial, Y_segsocial) 
gen asalud_1  = max(salud, Y_salud) 

recode asalud_1 asegsoci_1 (.=0)

gen  falta = 1 if asegsoci_1 <1 & pot_pag==1
egen falta_h =sum(falta),by (folio)
gen remanente2=remanente-ded_salud_ss_priv if falta_h>0 & remanente>0
gen con_remanete2=1 if remanente2 > (falta_h*SVO) & falta_h>0 & remanente>0
recode remanente2 con_remanete2 (.=0)

gen deducido_SVO_SVF =.
replace deducido_SVO_SVF=(falta_h*SVO) if con_remanete2==1
recode deducido_SVO_SVF (.=0)

replace Y_salud =1 if con_remanete2==1 & falta == 1
replace Y_segsocial=1 if con_remanete2==1 & falta == 1

************
*Se crea la variable con el costo total de salud y seguridad verificada por ingresos
**
gen total_ded_sal_ss_y = ded_salud_ss_priv + deducido_SVO_SVF

**Se resta del ingreso los gastos en salud. 
*Cuando el hogar puede pagar privadamente salud y seg social se deduce del ingreso la variable total_ded_sal_ss_y
*Cuando no, se utiliza la variabe def_j000

gen double yctradj_hogar = yctradj-def_j000 if total_ded_sal_ss_y==0
replace yctradj_hogar = yctradj-total_ded_sal_ss_y if total_ded_sal_ss_y>0

*Debido a que algunos hogares reportan bajos ingresos quedan como negativos al momento de deducir
*se procede a dejarlos en cero
replace yctradj_hogar=0 if yctradj_hogar<0
label var yctradj_hogar "Ingreso corr total mensual restando deducible incluyendo salud"

save "$tmp/saludssingreso.dta", replace

use "$tmp/saludssingreso.dta", clear

*se compara las variables creadas para verificar cobertura de salud y de seguridad social 
*a través de las reglas de parentesco con las de ingreso y se asiga a cada persona el valor 
*más alto.
*Seguridad social
gen asegsoci_y= max(segsocial, Y_segsocial) 
recode asegsoci_y (.=0)
gen ASSi=.
replace ASSi=asegsoci_y

*salud
gen asalud_y= max(salud, Y_salud) 
recode asalud_y (.=0)
gen ASi=.
replace ASi=asalud_y

*Carencia en seguridad social y salud
gen CASSi = 1 - (ASSi)
gen CASi  = 1 - (ASi)

labe var segsocial "Seguridad social del individuo directo y con reglas de parentesco "
label var Y_segsocial "Seguridad social del individuo con posibilidad de pago"
label var asegsoci_y "Seguridad social del individuo directo y con posibilidad de pago"
label var ASSi  "Adecuación de seguridad social del individuo directo y con posibilidad de pago"
label var CASSi "Carencia de seguridad social del individuo directo y con posibilidad de pago"

label var salud  "Salud del individuo directo"
label var Y_salud "Salud del individuo con posibilidad de pago"
label var asalud_y "Salud del individuo directo y con posibilidad de pago"
label var ASi  "Adecuación de salud del individuo directo y con posibilidad de pago"
label var CASi  "Carencia de salud del individuo directo y con posibilidad de pago"

keep folio numren segsocial Y_segsocial asegsoci_y ASSi CASSi salud Y_salud asalud_y ASi CASi

save "$final/saludyss.dta", replace

********************************************************************************
* Para ingreso
********************************************************************************

use "$tmp/saludssingreso.dta", replace

*Adecuación del ingreso corriente total del hogar
gen double ayj_LP = yctradj_hogar/ LP_N
label var ayj_LP "Adecuación del ingreso corriente total del hogar"

*rescalación del ingreso corriente total del hogar
gen double ayj_LP_P = ayj_LP
replace ayj_LP_P=0 if ayj_LP_P<=0

replace ayj_LP_P= 1+((ayj_LP- 1)/9) if (ayj_LP > 1)
replace ayj_LP_P=2 if ayj_LP_P> 2
recode  ayj_LP_P (.=0)

gen cyj_NLP = 1-(ayj_LP_P)
replace cyj_NLP=1 if cyj_NLP >= 1

label var cyj_NLP "carencia del ingreso corriente total del hogar"

keep folio numren mun_frio ur_rur_2500 municipio tam_hog tran_gobACN tran_nogobACN  YIDj  YISj  YISj2  p009_ACN p016_ACN remun_ACN imp_viv_ACN EBO_ACN transf_ACN renta_ACN  ing_total g1p_gasto g4p_gasto  g1h_gasto  g3h_gasto renta_d dedu1 yctrj   yctradj ing_men_hog ing_men_hog_stp ing_men_per ing_men_stp_per AE N_BREAK def_j000 LP_N  cyj_NLP ayj_LP 

label var AE "adulto equivalente"
label var LP_N "Línea de pobreza por hogar"
label var  def_j000 "Gastos de salud del hogar"


save "$final/cict.dta", replace

********************************************************************************
* Módulo 5. Tiempo 
********************************************************************************

*Se abre la base de población
use "$bases/poblacion.dta", clear 

*Se genera el folio 
egen folio=concat (folioviv foliohog)

*se pega la base de las variables imputadas de uso de uso de tiempo
merge 1:1 folio numren using "$tmp/imputado_tiempo.dta"
drop _merge

*Se eliminan los que no son miembros de la familia en el hogar
destring parentesco, replace
drop if parentesco>=400 & parentesco <500
drop if parentesco>=700 & parentesco <800

keep if edad>=12

********************************************************************************
*Construcción de variables que se necesitan
********************************************************************************
destring asis_esc, replace

*Grupos de edad 
gen grup_edad=.
replace grup_edad=4 if edad>=12 & edad<=14
replace grup_edad=5 if edad>=15 & edad<=17
replace grup_edad=6 if edad>=18 & edad<=69
replace grup_edad=7 if edad>=70 & edad<=79
replace grup_edad=8 if edad>=80

*se identificas a las personas que asisten a la escuela
gen asisten=.
replace asisten=1 if asis_esc==1
recode asisten (.=0)

*se identifican a las personas de 18 años o más que estudian educación superior
*Para los que han terminado preparatoria completa y asisten a la escuela
gen asis_edusuperior18ymas=.
replace asis_edusuperior18ymas=1 if edad>=18 & asisten==1 & (nivel>="10" & nivel<="13")  
recode asis_edusuperior18ymas (.=0)

*se identifican a las personas de 18 años o más con otros estudios
gen otrosestudios18ymas=.
replace otrosestudios18ymas=1 if edad>=18 & asisten==1 & (nivel>="01" & nivel<"10")
recode otrosestudios18ymas (.=0)

*se identifican a las personas de 18 a 69 años que no asisten a la escuela
gen noestudian_18a69=.
replace noestudian_18a69=1 if (edad>=18 & edad<=69) & asisten==0
recode noestudian_18a69 (.=0)

*se identifican a las personas de 70 a 79 años que no asisten a la escuela
gen noestudian_70a79=.
replace noestudian_70a79=1 if (edad>=70 & edad<=79) & asisten==0
recode noestudian_70a79 (.=0)

*se identifica a las personas de 80 o más que no asisten a la escuela
gen noestudian_80ymas=.
replace noestudian_80ymas=1 if edad>=80 & asisten==0
recode noestudian_80ymas (.=0)

*Personas con discapacidad y que por esa razón no trabajan
gen C_Disc_a=0
replace C_Disc=1 if act_pnea1=="5"
label var C_Disc "Personas con discapacidad y que por esa razón no trabajan"

********************************************************************************
*Construcción de NORMAS*
********************************************************************************

*Tiempo de Reproducción Individual (TRI) por grupos de edad
gen TRI=.
replace TRI=84 if grup_edad==4
replace TRI=80 if grup_edad==5
replace TRI=70 if asis_edusuperior18ymas==1
replace TRI=70 if otrosestudios18ymas==1
replace TRI=70 if noestudian_18a69==1
replace TRI=75 if noestudian_70a79==1
replace TRI=80 if noestudian_80ymas==1
recode TRI (.=0)

*TTrT=TTrED+TTrD+Trasl 
*TTrED= Tiempo de trabajo (trabajo domestico y extradomestico) más tiempo de traslado
gen TTrT=.
replace TTrT=24 if otrosestudios18ymas==1
replace TTrT=54 if noestudian_18a69==1
replace TTrT=12 if noestudian_70a79==1
replace TTrT= 6 if noestudian_80ymas==1
recode TTrT (.=0)

*Tiempo de estudio más traslados
*Agregar para los que unicamente a los que asisten a la escuela
gen TE_trasla=.
replace TE_trasla=40 if grup_edad==4 & asisten==1 
replace TE_trasla=44 if grup_edad==5 & asisten==1
replace TE_trasla=54 if asis_edusuperior18ymas==1
replace TE_trasla=30 if otrosestudios18ymas==1
replace TE_trasla= 0 if noestudian_18a69==1
replace TE_trasla= 0 if noestudian_70a79==1
replace TE_trasla= 0 if noestudian_80ymas==1
recode TE_trasla (.=0)

*Tiempo libre normativo 
gen TD_TL=168-(TRI+TTrT+TE_trasla)

********************************************************************************
*Tiempo reportado en la ENIGH 2018 imputado
********************************************************************************

*Tiempo de Reproducción Individual (TRI) para todas las personas
gen TRI_imp=.
replace TRI_imp=84 if grup_edad==4 
replace TRI_imp=80 if grup_edad==5 
replace TRI_imp=70 if asis_edusuperior18ymas==1 
replace TRI_imp=70 if otrosestudios18ymas==1 
replace TRI_imp=70 if noestudian_18a69==1
replace TRI_imp=75 if noestudian_70a79==1
replace TRI_imp=80 if noestudian_80ymas==1 
recode TRI_imp (.=0)

*se genera la variable que identifica las horas de trabajo reportadas e imputadas en el MUT-ENIGH, más el tiempo de traslado
*TTrED= Tiempo de trabajo = 1.1 trabajar? (incluya todo el tiempo dedicado a su trabajo extradoméstico)=hrs1_imp
*Trabajo extradoméstico más 6 hrs de traslado
gen TTrED_report=.
replace TTrED_report=(hrs1_imp+6) if hrs1_imp>0 
recode TTrED_report (.=0)

*Se genera la variable que identifica las horas de trabajo domestico de las personas según lo reportado en el MUT-ENIGH
*hrs6_imp lavar, planchar, cocinar, lavar trastes, barrer, cuidar animales de traspatio, etcétera
*hrs7_imp acarrear agua o leña
*hrs5_imp reparar o dar mantenimiento a su vivienda, muebles, aparatos domésticos o vehículos
*hrs3_imp realizar trabajo comunitario o voluntario
*hrs4_imp cuidar, atender sin pago y de manera exclusiva a niños, ancianos, enfermos, discapacitados
*Trabajo doméstico
gen TTrD_report=.
replace TTrD_report= (hrs6_imp+hrs7_imp+hrs5_imp+hrs3_imp+hrs4_imp) 
recode TTrD_report (.=0)

*Para saber el maximo de horas dedicados al trabajo domésticos
sum TTrD_report

*Se genera la variable que suma las horas de trabajo extradoméstico + trabajo domestico + traslado según lo reportado en el MUT-ENIGH
*Tiempo de trabajo total REPORTADO =TTrT_report
gen TTrT_report=.
replace TTrT_report= TTrED_report+TTrD_report
recode TTrT_report (.=0)

*Se genera la variable que identifica horas de estudio según lo reportado en el MUT-ENIGH
* 1.2 estudiar y hacer actividades relacionadas con el estudio?
*Tiempo de estudio y traslado reportado
gen TE_trasla_report=.
replace TE_trasla_report=hrs2_imp
recode TE_trasla_report (.=0)

*suma total 
gen TObl=TTrT_report+TE_trasla_report

*Se establece un máximo conceptual de TObl, que es tiempo de trabajo doméstico más*
* tiempo de trabajo extra domméstico más estudio y traslados, por grupo de edad
gen TObl_1=TObl
replace TObl_1=84 if grup_edad==4 & TObl>84
replace TObl_1=88 if grup_edad==5 & TObl>88
replace TObl_1=98 if grup_edad==6 & TObl>98
replace TObl_1=93 if grup_edad==7 & TObl>93
replace TObl_1=88 if grup_edad==8 & TObl>88

****

*Se genera la variable tiempo disponible según lo reportado en el MUT-ENIGH
*Tiempo disponible 
gen TD_TL_report=[168-(TRI_imp+TObl_1)]   

********************************************************************************
*Construcción de logro con TL como residuo restando los demás usos del tiempo
*******************************************************************************

*Logro de tiempo libre
gen LTL=TD_TL_report/TD_TL 
label var LTL "Logro de tiempo disponible de las personas"

*Logro de tiempo libre reescalado
gen LTL_rees=1+((LTL-1)*( 0.4065)) if LTL>1 
replace LTL_rees=LTL if LTL<=1 
label var LTL_rees "Logro de tiempo disponible reescalado"

*Carencia de tiempo 
gen CTL=1-LTL_rees
label var CTL "Carencia de tiempo libre"

keep folio numren CTL parentesco

save "$tmp/CTL_persona.dta", replace

*Por hogar
use "$tmp/CTL_persona.dta", clear

egen CTL_p=mean(CTL), by (folio)
label var CTL_p "Promedio de la carencia de tiempo libre del hogar"
keep if parentesco==101
keep folio CTL_p

save "$tmp/CTL_hogar.dta", replace

*Pegado
use "$bases/poblacion.dta", clear 
egen folio=concat (folioviv foliohog)
*Se eliminan los que no son miembros de la familia en el hogar
destring parentesco, replace
drop if parentesco>=400 & parentesco <500
drop if parentesco>=700 & parentesco <800
drop parentesco

merge 1:1 folio numren using  "$tmp/CTL_persona.dta"
drop _merge

merge m:1 folio using  "$tmp/CTL_hogar.dta"
drop _merge

gen CTL1=.
replace CTL1=CTL
replace CTL1=CTL_p if edad<12


label var CTL1 "Carencia de tiempo libre por persona"
keep folio numren CTL1


save "$final/tiempo.dta", replace 

********************************************************************************
* Módulo 7.- Cálculo de indicador de MMIP
* 7.1 Pegar las bases finales y quedarse con una sola de trabajo
* 7.2 Calcular el NBI y el MMIP
* 7.3 Generar los Estratos del MMIP
* 7.4 Guardado de base final
********************************************************************************

* 7.1 Pegado de bases

*Abrir base de población y se genera folio
use "$bases/poblacion.dta", clear
egen folio=concat(folioviv foliohog)
sort  folio
	
*Se eliminan los que no son miembros de la familia en el hogar
destring parentesco, replace
drop if parentesco>=400 & parentesco <500
drop if parentesco>=700 & parentesco <800

keep folio numren sexo edad hablaind lenguaind hablaesp comprenind etnia alfabetism edo_conyug parentesco disc* nivel nivelaprob asis_esc gradoapro inst_* segvol_2 segpop
	
*Pegar con base de factor	
merge m:1 folio using "$final/factexp.dta"
drop _merge

*Pegar con la base de NBI
merge m:1 folio using "$final/nbi.dta"
drop _merge

*Pegar con la base de tiempo
merge 1:1 folio numren using "$final/tiempo.dta"
drop _merge

*Pegar con la base de educación
merge 1:1 folio numren using "$final/edu.dta"
drop _merge

*Pegar con la base de ingresos
merge 1:1 folio numren using "$final/cict.dta"
drop _merge

*Pegar con la base Salud y seguridad social
merge 1:1 folio numren using "$final/saludyss.dta"
drop _merge


***
***Guardar una base final con las bases pegadas para trabajar y hacer calculos
***
save "$final/basefinal_pegadas.dta", replace

* 7.2 Cálculos de  NBI y MMIP

*Abrir base con todas las demas ya   
use "$final/basefinal_pegadas.dta", clear

*recode totaldehrs_dicotomico (.=0)

*Construcción de deciles 
xtile decil_lp= ayj_LP [fw=factor], nq(10)
xtile decil_lp_cdmx= ayj_LP [fw=factor] if entidad==09, nq(10)

tab decil_lp [fw=factor]
tab decil_lp_cdmx [fw=factor]

*Construcción Discapacidad 
destring disc1, replace force
destring disc2 disc3 disc4 disc5 disc6 disc7, replace

*Indentificar discpaacidaddes
recode disc1 (1/7=1) (8=0), gen(discapacidad1)
recode disc2 (2/7=1) (.=0), gen(discapacidad2)
recode disc3 (3/7=1) (.=0), gen(discapacidad3)
recode disc4 (4/7=1) (.=0), gen(discapacidad4)
recode disc5 (5/7=1) (.=0), gen(discapacidad5)
recode disc6 (6/7=1) (.=0), gen(discapacidad6)
recode disc7 (7=1)   (.=0), gen(discapacidad7)

gen sum_discapacidades= discapacidad1+discapacidad2+discapacidad3+discapacidad4+discapacidad5+discapacidad6+discapacidad7

gen num_disc=0
replace num_disc=1 if sum_discapacidades==1
replace num_disc=2 if sum_discapacidades==2
replace num_disc=3 if sum_discapacidades>=3 & sum_discapacidades<=8
tab num_disc
tab num_disc [w=factor]
gen discapacidad =.
replace discapacidad =0 if num_disc ==0
replace discapacidad =1 if num_disc >0
tab discapacidad [fw=factor]

drop discapacidad1 discapacidad2 discapacidad3 discapacidad4 discapacidad5 discapacidad6 discapacidad7 sum_discapacidades num_disc


*Generar indicador de NBI
gen nbi= [(CCEVj*.328) + (CSj*.037) + (CENj*.028) + (CTELJ*.030) +  (CBDj *.058) + (Rei*.236) + (CASSi*.1415) + (CASi*.1415)] 
label variable nbi "Indice global NBI"

gen MMIP=(nbi*0.33)+ (cyj_NLP*0.40)+ (CTL1*0.27)
label variable MMIP "Indice Pobreza MMIP"


* 7.3 Generar los Estratos del MMIP

*** Etiqueta de Estratos
label define Estratos 6"Estratos alto" 5"Estratos medio" 4"Satisfaccion mínima" 3"Pobreza moderada" 2"Pobreza alta" 1"Pobreza muy alta"

* 1. Estratos de calidad de espacio de la vivienda
gen E_ccevj=.
replace E_ccevj=6 if CCEVj <=-0.5
replace E_ccevj=5 if (CCEVj > -0.5 & CCEVj <= -.1) 
replace E_ccevj=4 if (CCEVj > -0.1 & CCEVj <= 0) 
replace E_ccevj=3 if (CCEVj > 0 & CCEVj <= (1/3)) 
replace E_ccevj=2 if (CCEVj > (1/3) & CCEVj <= .5) 
replace E_ccevj=1 if (CCEVj > .5 & CCEVj <= 1) 
label var E_ccevj "Estratos de Calidad y Espacio de la Vivienda"
label values E_ccevj Estratos

***
*Calidad y Espacio de la Vivienda
gen pobreza_ccevj=.
replace pobreza_ccevj=0 if E_ccevj>=4
replace pobreza_ccevj=1 if E_ccevj<=3
label var pobreza_ccevj "Pobreza por Calidad y Espacio de la Vivienda"

gen pobre_ext_ccevj=.
replace pobre_ext_ccevj=0 if E_ccevj>=3
replace pobre_ext_ccevj=1 if E_ccevj<=2
label var pobre_ext_ccevj "Pobreza extrema por Calidad y Espacio de la Vivienda"


* 2. Estratos de carencia de bienes durables
gen E_CBDj=.
replace E_CBDj=6 if CBDj<= -0.5                  
replace E_CBDj=5 if (CBDj> -0.5 & CBDj <= -.1) 
replace E_CBDj=4 if (CBDj> -0.1 & CBDj <= 0) 
replace E_CBDj=3 if (CBDj> 0 & CBDj <= (1/3)) 
replace E_CBDj=2 if (CBDj> (1/3) & CBDj <=.5) 
replace E_CBDj=1 if (CBDj> .5 & CBDj <= 1) 
label var E_CBDj "Estratos de carencia de bienes durables"
label values E_CBDj Estratos

***
*Carencia de bienes durables 
gen pobreza_cbdj=.
replace pobreza_cbdj=0 if E_CBDj>=4
replace pobreza_cbdj=1 if E_CBDj<=3
label var pobreza_cbdj "Pobreza por Bienes durables"

gen pobre_ext_cbdj=.
replace pobre_ext_cbdj=0 if E_CBDj>=3
replace pobre_ext_cbdj=1 if E_CBDj<=2
label var pobre_ext_cbdj "Pobreza extrema por Bienes durables"


* 3. Estratos de adecuación sanitaria
gen E_CSj =.
replace E_CSj=6 if CSj<= -0.5                  
replace E_CSj=5 if (CSj> -0.5 & CSj <= -.1) 
replace E_CSj=4 if (CSj> -0.1 & CSj <= 0) 
replace E_CSj=3 if (CSj> 0 & CSj <= (1/3)) 
replace E_CSj=2 if (CSj> (1/3) & CSj <=.5) 
replace E_CSj=1 if (CSj> .5 & CSj <= 1) 
label var E_CSj "Estratos de adecuación sanitaria"
label values E_CSj Estratos

***
*Adecuacion sanitaria
gen pobreza_csj=.
replace pobreza_csj=0 if E_CSj>=4
replace pobreza_csj=1 if E_CSj<=3
label var pobreza_csj "Pobreza por Adecuacion Sanitaria"

gen pobre_ext_csj=.
replace pobre_ext_csj=0 if E_CSj>=3
replace pobre_ext_csj=1 if E_CSj<=2
label var pobre_ext_csj "Pobreza extrema por Adecuacion Sanitaria"


* 4. Estratos de carencia de teléfono
gen E_CTELJ=.
replace E_CTELJ=6 if CTELJ <= -0.5                  
replace E_CTELJ=5 if (CTELJ > -0.5 & CTELJ <= -.1) 
replace E_CTELJ=4 if (CTELJ > -0.1 & CTELJ <= 0) 
replace E_CTELJ=3 if (CTELJ > 0 & CTELJ <= (1/3)) 
replace E_CTELJ=2 if (CTELJ > (1/3) & CTELJ <=.5) 
replace E_CTELJ=1 if (CTELJ > .5 & CTELJ <= 1) 
label var E_CTELJ  "Estratos de carencia de servicio de telecomunicaciones "
label values E_CTELJ Estratos
***
*Carencia de Teléfono
gen pobreza_ctelj=.
replace pobreza_ctelj=0 if E_CTELJ>=4
replace pobreza_ctelj=1 if E_CTELJ<=3
label var pobreza_ctelj "Pobreza por Carencia de servicio de telecomunicaciones "

gen pobre_ext_ctelj=.
replace pobre_ext_ctelj=0 if E_CTELJ>=3
replace pobre_ext_ctelj=1 if E_CTELJ<=2
label var pobre_ext_ctelj "Pobreza extrema por Carencia de  servicio de telecomunicaciones "


* 5. Estratos de carencia energética
gen E_CENJ=.
replace E_CENJ=6 if CENj <= -0.5                  
replace E_CENJ=5 if (CENj > -0.5 & CENj <= -.1) 
replace E_CENJ=4 if (CENj > -0.1 & CENj <= 0) 
replace E_CENJ=3 if (CENj > 0 & CENj <= (1/3)) 
replace E_CENJ=2 if (CENj > (1/3) & CENj <=.5) 
replace E_CENJ=1 if (CENj > .5 & CENj <= 1) 
label var E_CENJ "Estratos de carencia energética"
label values E_CENJ Estratos  

***
*Carencia Energética
gen pobreza_cenj=.
replace pobreza_cenj=0 if E_CENJ>=4
replace pobreza_cenj=1 if E_CENJ<=3
label var pobreza_cenj "Pobreza por Carencia Energética"

gen pobre_ext_cenj=.
replace pobre_ext_cenj=0 if E_CENJ>=3
replace pobre_ext_cenj=1 if E_CENJ<=2
label var pobre_ext_cenj "Pobreza extrema por Carencia Energética"


* 6. Estratos de rezago educativo
gen E_rei=.
replace E_rei=6 if  Rei <= -0.5                  
replace E_rei=5 if (Rei > -0.5 & Rei <= -.1) 
replace E_rei=4 if (Rei > -0.1 & Rei <= 0) 
replace E_rei=3 if (Rei > 0 & Rei <= (1/3)) 
replace E_rei=2 if (Rei > (1/3) & Rei <=.5) 
replace E_rei=1 if (Rei > .5 & Rei <= 1) 
label var E_rei  "Estratos de rezago educativo"
label values E_rei Estratos  

***
*Rezago Educativo
gen pobreza_rei=.
replace pobreza_rei=0 if E_rei>=4 & E_rei<=6 
replace pobreza_rei=1 if E_rei>=1 & E_rei<=3 
label var pobreza_rei "Pobreza por Rezago educativo"

gen pobre_ext_rei=.
replace pobre_ext_rei=0 if E_rei>=3
replace pobre_ext_rei=1 if E_rei<=2
label var pobre_ext_rei "Pobreza extrema por Rezago educativo"


*7 Generar indicador de carencia de Seguridad Social
gen E_CASSi=.
replace E_CASSi=6 if CASSi <=  -0.5
replace E_CASSi=5 if (CASSi >  -0.5 & CASSi <= -.1)
replace E_CASSi=4 if (CASSi >  -0.1 & CASSi <= 0)
replace E_CASSi=3 if (CASSi >     0 & CASSi <= (1/3))
replace E_CASSi=2 if (CASSi > (1/3) & CASSi <=.5)
replace E_CASSi=1 if (CASSi >    .5 & CASSi <= 1)
label var E_CASSi "Estratos de Acceso a Seguridad Social"
label values E_CASSi Estratos

*Pobreza de acceso a Salud
gen pobreza_CASSi=.
replace pobreza_CASSi=0 if E_CASSi>=4
replace pobreza_CASSi=1 if E_CASSi<=3
label var pobreza_CASSi "Pobreza de acceso a Seguridad Social"

gen pobre_ext_CASSi=.
replace pobre_ext_CASSi=0 if E_CASSi>=3
replace pobre_ext_CASSi=1 if E_CASSi<=2
label var pobre_ext_CASSi "Pobreza extrema de acceso a Seguridad social"

*8 Generar indicador de carencia de Salud
gen E_CASi=.
replace E_CASi=6 if CASi <=  -0.5
replace E_CASi=5 if (CASi >  -0.5 & CASi <= -.1)
replace E_CASi=4 if (CASi >  -0.1 & CASi <= 0)
replace E_CASi=3 if (CASi >     0 & CASi <= (1/3))
replace E_CASi=2 if (CASi > (1/3) & CASi <=.5)
replace E_CASi=1 if (CASi >    .5 & CASi <= 1)
label var E_CASi "Estratos de Acceso a Salud"
label values E_CASi Estratos

*Pobreza de acceso a Salud
gen pobreza_CASi=.
replace pobreza_CASi=0 if E_CASi>=4
replace pobreza_CASi=1 if E_CASi<=3
label var pobreza_CASi "Pobreza de acceso a Salud"

gen pobre_ext_CASi=.
replace pobre_ext_CASi=0 if E_CASi>=3
replace pobre_ext_CASi=1 if E_CASi<=2

label var pobre_ext_CASi "Pobreza de acceso a Salud"


* 9. Estratos de Necesidades Básicas Insatisfechas 
gen E_nbi=.
replace E_nbi=6 if (nbi  <= -0.5)                  
replace E_nbi=5 if (nbi  > -0.5   & nbi  <= -.1) 
replace E_nbi=4 if (nbi  > -0.1   & nbi  <= 0) 
replace E_nbi=3 if (nbi  > 0      & nbi  <= (1/3)) 
replace E_nbi=2 if (nbi  > (1/3)  & nbi  <=.5) 
replace E_nbi=1 if (nbi  > .5     & nbi  <= 1) 
label var E_nbi  "Estratos de Necesidades Básicas Insatisfechas"
label values E_nbi Estratos
    

***
*Pobreza por NBI
gen pobreza_nbi=.
replace pobreza_nbi=0 if E_nbi>=4
replace pobreza_nbi=1 if E_nbi<=3
label var pobreza_nbi "Pobreza por NBI"

gen pobre_ext_nbi=.
replace pobre_ext_nbi=0 if E_nbi>=3
replace pobre_ext_nbi=1 if E_nbi<=2
label var pobre_ext_nbi "Pobreza extrema por NBI"

* 10. Estratos de ingreso
gen E_cict=.
replace E_cict=6 if ( cyj_NLP  <= -0.5)
replace E_cict=5 if ( cyj_NLP  >  -0.5  &  cyj_NLP  <= -0.1)
replace E_cict=4 if ( cyj_NLP  >  -0.1  &  cyj_NLP  <= 0)
replace E_cict=3 if ( cyj_NLP  >    0   &  cyj_NLP  <= (1/3))
replace E_cict=2 if ( cyj_NLP  > (1/3)  &  cyj_NLP  <= 0.5)
replace E_cict=1 if ( cyj_NLP  >  0.5   &  cyj_NLP  <= 1)
label var E_cict "Estratos del ingreso"
label values E_cict Estratos

***
*Pobreza por Ingreso
gen pobreza_cict=.
replace pobreza_cict=0 if E_cict>=4
replace pobreza_cict=1 if E_cict<=3
label var pobreza_cict "Pobreza por Ingreso"

gen pobre_ext_cict=.
replace pobre_ext_cict=0 if E_cict>=3
replace pobre_ext_cict=1 if E_cict<=2
label var pobre_ext_cict "Pobreza extrema por Ingreso"


***
*Estratos del Indicador de Carencia de Tiempo
gen E_CTL=.
replace E_CTL=6 if  CTL1 <= -0.5  
replace E_CTL=5 if (CTL1 >  -0.5  & CTL1 <= -.1)
replace E_CTL=4 if (CTL1 >  -0.1  & CTL1 <=  0)
replace E_CTL=3 if (CTL1 >    0   & CTL1 <=  (1/3))
replace E_CTL=2 if (CTL1 > (1/3)  & CTL1 <=  0.5 )
replace E_CTL=1 if (CTL1 >  0.5   & CTL1 <=  1)
label var E_CTL "Estratos del Indicador de Carencia de Tiempo"
label values E_CTL Estratos


*Pobreza por tiempo
gen pobreza_ctl=.
replace pobreza_ctl=0 if E_CTL>=4 & E_CTL<=6
replace pobreza_ctl=1 if E_CTL>=1 &  E_CTL<=3
label var pobreza_ctl "Pobreza tiempo"

gen pobre_ext_ctl=.
replace pobre_ext_ctl=0  if E_CTL>=3
replace pobre_ext_ctl=1 if E_CTL<=2
label var pobre_ext_ctl "Pobreza tiempo"

* 13. Estratos del MMIP
gen E_mmip=.
replace E_mmip=6 if  MMIP <= -0.5  
replace E_mmip=5 if (MMIP  >  -0.5  & MMIP  <= -.1)
replace E_mmip=4 if (MMIP  >  -0.1  & MMIP  <=  0)
replace E_mmip=3 if (MMIP  >    0   & MMIP  <=  (1/3))
replace E_mmip=2 if (MMIP  > (1/3)  & MMIP  <=  0.5 )
replace E_mmip=1 if (MMIP  >  0.5   & MMIP  <=  1)
label var E_mmip "Estratos del MMIP"
label values E_mmip Estratos

*Pobreza por Ingreso
gen pobreza_mmip=.
replace pobreza_mmip=0 if E_mmip>=4
replace pobreza_mmip=1 if E_mmip<=3
label var pobreza_mmip "Pobreza por MMIP" 

gen pobre_ext_mmip=.
replace pobre_ext_mmip=0 if E_mmip>=3
replace pobre_ext_mmip=1 if E_mmip<=2
label var pobre_ext_mmip "Pobreza por MMIP"

recode disc* (.=0)
recode tarifa_* (.=2)

destring sexo edo_conyug etnia hablaind alfabetism asis_esc nivel nivelaprob gradoaprob segpop ///
          inst_* segvol_2, replace
		 
*Etiquetar
label var	folio            "Identificador de la vivienda y el hogar"
label var	folioviv	     "Identificador de la vivienda"
label var	foliohog	     "Identificador del hogar"
label var	ubica_geo	     "Ubicación geográfica"
label var	numren	         "Identificador de la persona"
label var	upm	             "Unidad primaria de muestreo"
label var	est_dis	         "Estrato de diseño muestral"
label var	factor	         "Factor de expansión"
label var	parentesco	     "Parentesco con el jefe del hogar (consultar catálogo de la ENIGH 2018 del INEGI)"
label var	tam_hog	         "Tamaño del hogar"
label var	municipio	     "Identificador del Municipio (consultar catálogo de la ENIGH 2018 del INEGI)"
label var	sexo	         "Sexo"
label define sexo            1 "Hombre" 2 "Mujer" 
label values sexo sexo
label var   edad	         "Edad reportada al momento de la entrevista"
label var	edo_conyug	     "Situación conyugal del integrante del hogar de 12 años o más"
label define edo_conyug      1 "Vive con su pareja o en unión libre" 2 "Está casado(a)" 3 "Está separado(a)" ///
                             4 "Está divorciado(a)" 5 "Es viudo(a)" 6 "Está soltero(a)" 
label values edo_conyug edo_conyug
label var	etnia	         "Personas de 3 años o más de acuerdo con su cultura se consideran indígenas"
label define etnia           1 "Sí" 2 "No"
label values etnia etnia
label var	lenguaind	     "Lengua indígena o dialecto que hablan los residentes de la vivienda de 3 años o más. (consultar catálogo de la ENIGH 2018 del INEGI)"
label var	hablaind	     "Personas de 3 años o más que hablan alguna lengua indígena o dialecto"
label define hablaind        1 "Sí" 2 "No"
label values hablaind hablaind
label var	alfabetism	     "Personas de 3 o más años según sepan leer y escribir un recado"
label define alfabetism      1 "Sí" 2 "No"
label values alfabetism alfabetism
label var	asis_esc	     "Personas de 3 o más años según asisten o no a algún establecimiento de enseñanza escolar del Sistema Educativo Nacional (SEN), en cualquier nivel"
label define asis_esc        1 "Sí" 2 "No"
label values asis_esc asis_esc
label var	nivel	         "Nivel al que asiste a la escuela el integrante del hogar de 3 o más años dentro del Sistema Educativo Nacional"
label define nivel           1 "Preescolar" 2 "Estancias infantiles" 3 "Guarderías públicas (IMSS, ISSSTE, SEDENA, SEMAR, PEMEX)"                 ///
                             4 "Centro de Desarrollo Infantil (CENDI) o Centro Asistencial de Desarrollo Infantil (CADI)" 5 "Otras guarderías"    ///
				             6 "Primaria" 7 "Secundaria" 8 "Carrera técnica con secundaria terminada" 9 "Preparatoria o bachillerato"             ///
				             10 "Carrera técnica con preparatoria terminada" 11 "Normal" 12 "Profesional" 13 "Maestría o doctorado"
label values nivel nivel
label var nivelaprob	     "Año máximo aprobado en la escuela, por el integrante del hogar de 3 o más años dentro del Sistema Educativo Nacional"
label define nivelaprob      0 "Ninguno" 1 "Preescolar" 2 "Primaria" 3 "Secundaria" 4 "Preparatoria o bachillerato" 5 "Normal" 6 "Carrera técnica o comercial"   ///
                             7 "Profesional" 8 "Maestría" 9 "Doctorado" 
label values nivelaprob nivelaprob
label var gradoaprob	     "Grado máximo aprobado en la escuela, por el integrante del hogar de 3 o más años dentro del Sistema Educativo Nacional"
label define gradoaprob      0 "Ninguno" 1 "Primer año" 2 "Segundo año" 3 "Tercer año" 4 "Cuarto año" 5 "Quinto año" 6 "Sexto año"
label values gradoaprob gradoaprob
label var	disc1	         "Discapacidad 1"
label define disc1           1 "Caminar, moverse, subir o bajar" 2 "Ver, aun usando lentes" 3 "Hablar, comunicarse o conversar" 4 "Oír, aun usando aparato auditivo" 5 "Vestirse, bañarse o comer" 6 "Poner atención o aprender cosas sencillas" 7 "Tiene alguna limitación mental" 8 "No tiene dificultad física o mental"
label values disc1 disc1
label var	disc2            "Discapacidad 2"
label define disc2           2 "Ver, aun usando lentes" 3 "Hablar, comunicarse o conversar" 4 "Oír, aun usando aparato auditivo" 5 "Vestirse, bañarse o comer" 6 "Poner atención o aprender cosas sencillas" 7 "Tiene alguna limitación mental"
label values disc2 disc2
label var	disc3	         "Discapacidad 3"
label define disc3           3 "Hablar, comunicarse o conversar" 4 "Oír, aun usando aparato auditivo" 5 "Vestirse, bañarse o comer" 6 "Poner atención o aprender cosas sencillas" 7 "Tiene alguna limitación mental"
label values disc3 disc3
label var	disc4	         "Discapacidad 4"
label define disc4           4 "Oír, aun usando aparato auditivo" 5 "Vestirse, bañarse o comer" 6 "Poner atención o aprender cosas sencillas" 7 "Tiene alguna limitación mental"
label values disc4 disc4
label var	disc5	         "Discapacidad 5"
label define disc5           5 "Vestirse, bañarse o comer" 6 "Poner atención o aprender cosas sencillas" 7 "Tiene alguna limitación mental"
label values disc5 disc5
label var	disc6	         "Discapacidad 6"
label define disc6           6 "Poner atención o aprender cosas sencillas" 7 "Tiene alguna limitación mental"
label values disc6 disc6
label var	disc7	         "Discapacidad 7"
label define disc7           7 "Tiene alguna limitación mental"
label values disc7 disc7
label var	discapacidad	 "Población en situación de discapacidad"
label define discapacidad    1 "Sí" 2 "No"
label values discapacidad discapacidad
label var	segpop	     "Afiliación al Seguro Popular"
label define segpop          1 "Sí" 2 "No"
label values segpop segpop
label var	inst_1	        "Institución médica IMSS"
label define inst_1          1 "IMSS"
label values inst_1 inst_1
label var	inst_2	         "Institución médica ISSSTE"
label define inst_2          2 "ISSSTE"
label values inst_2 inst_2
label var	inst_3	         "Institución médica ISSSTE estatal"
label define inst_3          3 "ISSSTE estatal"
label values inst_3 inst_3
label var	inst_4	         "Institución médica PEMEX"
label define inst_4          4 "PEMEX"
label values inst_4 inst_4
label var	inst_5	         "Institución médica IMSS-Prospera/IMSS-Bienestar"
label define inst_5          5 "IMSS-Prospera/IMSS-Bienestar"
label values inst_5 inst_5
label var	inst_6	         "Otra institución médica"
label define inst_6          6 "Otro"
label values inst_6 inst_6
label var	segvol_2	     "Seguro voluntario de gastos médicos"
label define segvol_2        2 "Seguro privado de gastos médicos"
label values segvol_2 segvol_2
label var	tarifa_1	     "Tarifa doméstica 1, predominante en el municipio conforme a la CFE 2017"
label define tarifa_1        1 "Sí" 2 "No"
label values tarifa_1 tarifa_1
label var	tarifa_1A	     "Tarifa doméstica 1A, predominante en el municipio conforme a la CFE 2017"
label define tarifa_1A       1 "Sí" 2 "No"
label values tarifa_1A tarifa_1A
label var	tarifa_1B	     "Tarifa doméstica 1B, predominante en el municipio conforme a la CFE 2017"
label define tarifa_1B       1 "Sí" 2 "No"
label values tarifa_1B tarifa_1B
label var	tarifa_1C	     "Tarifa doméstica 1C, predominante en el municipio conforme a la CFE 2017"
label define tarifa_1C       1 "Sí" 2 "No"
label values tarifa_1C tarifa_1C
label var	tarifa_1D	    "Tarifa doméstica 1D, predominante en el municipio conforme a la CFE 2017"
label define tarifa_1D       1 "Sí" 2 "No"
label values tarifa_1D tarifa_1D
label var	tarifa_1E	     "Tarifa doméstica 1E, predominante en el municipio conforme a la CFE 2017"
label define tarifa_1E       1 "Sí" 2 "No"
label values tarifa_1E tarifa_1E
label var	tarifa_1F	    "Tarifa doméstica 1F, predominante en el municipio conforme a la CFE 2017"
label define tarifa_1F       1 "Sí" 2 "No"
label values tarifa_1F tarifa_1F
label var	mun_frio	     "Municipios en donde los hogares requieren calefacción"
label define mun_frio        0 "No" 1 "Sí" 
label values mun_frio mun_frio
label var	AMj	             "Adecuación de muros"
label var	ATj	             "Adecuación de techos"
label var	APj	             "Adecuación de pisos"
label var	ACVj	         "Indicador de logro compuesto de calidad de la vivienda"
label var	ADh	             "Indicador de logro de dormitorios de la vivienda"
label var	CTBj	         "Indicador de cuartos totales de la vivienda (incluyendo baño)	"
label var	AEVh	         "Indicador de logro de espacios de la vivienda	"
label var	AEVh_P	         "Indicador de logro espacios de la vivienda (reescalado)"
label var	HMDh	         "Indicador de hacinamiento multidimensional de la vivienda"
label var	ACEVj	         "Indicador de logro de espacio y calidad de la vivienda"
label var	CCEVj	         "Indicador de carencia en espacio y calidad de la vivienda del hogar"
label var	ABDj_P	         "Indicador de logro de bienes durables (reescalado)"
label var	CBDj	         "Indicador de carencia de bienes durables del hogar"
label var	AAj	             "Indicador de logro de forma de abasto hídrica"
label var	AFAj	         "Indicador de logro de frecuencia del agua"
label var	AAHj	         "Indicador de logro de abasto hídrico"
label var	ADrj	         "Indicador de logro del drenaje"
label var	AEXj	         "Indicador de logro del excusado"
label var	ASj	             "Indicador de logro consolidado de adecuación sanitaria"
label var	CSj	             "Indicador de carencia sanitaria del hogar"
label var	ATlj	         "Indicador de logro de telefonía"
label var	Ij	             "Indicador de logro de internet"
label var	ACTI	         "Indicador de logro de telecomunicaciones"
label var	IVj	             "Indicador de carencia de internet"
label var	CTELJ	         "Indicador de carencia del servicio telecomunicaciones del hogar"
label var	AElj	         "Indicador logro de acceso a electricidad"
label var	LFj_P	         "Indicador de logro de focos (reescalado)"
label var	LIEI	         "Indicador de logro de electricidad"
label var	PIEI	         "Indicador de carencia de electricidad integral"
label var	ACK	             "Indicador de logro combustible"
label var	PCK	             "Indicador de carencia de combustible"
label var	AENj	         "Indicador de logro energético"
label var	CENj	         "Indicador de carencia energética del hogar"
label var	rescgeni         "Años de escolaridad de las personas de 3 años o más"
label var	ANEi	         "Indicador de logro de educación de las personas de 3 años o más"
label var	ANEi_P	         "Indicador de logro de educación de las personas de 3 años o más (reescalado)"
label var	Rei	             "Indicador de rezago educativo de las personas"
label var	segsocial        "Indicador de logro de seguridad social de las personas (directo y con reglas de parentesco)"
label var	salud	         "Indicador de logro de salud de las personas (directo y con reglas de parentesco)"
label var	Y_segsocial	     "Indicador de logro de seguridad social de las personas (con posibilidad de pago)"
label var	Y_salud	         "Indicador de logro de salud de las personas (con posibilidad de pago)"
label var	ASSi	         "Indicador de logro en seguridad social de las personas (directo y con posibilidad de pago según su ingreso del hogar)"
label var	ASi	             "Indicador de logro en salud de las personas (directo y con posibilidad de pago según su ingreso del hogar)"
label var	CASSi	         "Indicador de carencia de seguridad social de las personas (directo y con posibilidad de pago)"
label var	CASi	         "Indicador de carencia de salud de las personas (directo y con posibilidad de pago)"
label var	YIDj	         "Ingreso monetario mensual del hogar por indemnización de seguros contra riesgos a terceros (ajustado a cuentas nacionales)"
label var	YISj	         "Ingreso monetario mensual del hogar por indemnización por accidentes de trabajo (ajustado a cuentas nacionales)"
label var	YISj2	         "Ingreso monetario mensual del hogar por indemnización por despido y retiro involuntario (ajustado a cuentas nacionales)"
label var	p009_ACN         "Ingreso monetario mensual del hogar del aguinaldo del ejercicio 2017 ajustado a cuentas nacionales (Trabajo principal)"
label var	p016_ACN         "Ingreso monetario mensual del hogar del aguinaldo del ejercicio 2017 ajustado a cuentas nacionales (Trabajo principal)"
label var	ing_total        "Ingreso corriente total mensual del hogar (ajustado a cuentas nacionales)"
label var	remun_ACN	     "Ingreso corriente total mensual del hogar por trabajo subordinado (ajustado a cuentas nacionales)"
label var	imp_viv_ACN	     "Ingreso monetario mensual del hogar por alquiler (ajustado a cuentas nacionales)"
label var	EBO_ACN	         "Ingreso monetario mensual del hogar por negocios (ajustado a cuentas nacionales)"
label var	transf_ACN	     "Ingreso monetario mensual del hogar por transferencias (ajustado a cuentas nacionales)"
label var	tran_gobACN	     "Ingreso monetario mensual del hogar por transferencias de gobierno (ajustado a cuentas nacionales)"
label var	tran_nogobACN	 "Ingreso monetario mensual del hogar por transferencias de no gubernamentales (ajustado a cuentas nacionales)"
label var	renta_ACN	     "Ingreso monetario mensual del hogar por renta de la propiedad (ajustado a cuentas nacionales)"
label var	g1p_gasto	     "Suma de gastos monetarios mensual para deducir de bienes y servicios para el hogar"
label var	g4p_gasto	     "Suma de gastos no monetarios mensual para deducir de remuneraciones en especie"
label var	g1h_gasto	     "Suma de gastos monetarios mensual para deducir de bienes y servicios  para el hogar y otros"
label var	g3h_gasto	     "Suma de gastos no monetarios mensuales para deducir autoconsumo, regalos, transferencias, alquiler"
label var	renta_d	         "Renta mensual de la vivienda"
label var	dedu1	         "Suma de gastos mensual NBI deflactado agosto 2018"
label var	yctrj	         "Ingreso corriente total mensual del hogar redefinido"
label var	yctradj	         "Ingreso corriente total mensual del hogar restando deducible excepto salud"
label var	ing_men_hog	     "Ingreso corriente total mensual por hogar (ajustado a cuentas nacionales)"
label var	ing_men_hog_stp	 "Ingreso corriente total mensual por hogar sin transferencias públicas (ajustado a cuentas nacionales)"
label var	ing_men_per	     "Ingreso corriente total mensual per cápita (ajustado a cuentas nacionales)"
label var	ing_men_stp_per	 "Ingreso corriente total mensual por hogar sin transferencias per cápita (ajustado a cuentas nacionales)"
label var	AE	             "Adulto equivalente"
label var	def_j000	     "Gasto monetario mensual en salud del hogar"
label var	LP_N	         "Línea de pobreza mensual del hogar"
label var	ayj_LP	         "Indicador de logro del ingreso mensual corriente total del hogar"
label var	decil_lp	     "Deciles Nacionales  (las personas están ordenados de acuerdo con el ingreso total del hogar entre su línea de pobreza)"
label var	decil_lp_cdmx	 "Deciles Ciudad de México (las personas están ordenados de acuerdo con el ingreso total del hogar entre su línea de pobreza)"
label var	cyj_NLP	         "Indicador de carencia del ingreso corriente total mensual del hogar"
label var	nbi	             "Índice global NBI"
label var	CTL1	         "Indicador de carencia de tiempo libre de las personas"
label var	MMIP	         "Índice Pobreza MMIP"
label var	E_ccevj	         "Estratos de Calidad y Espacio de la Vivienda"
label var	pobreza_ccevj	 "Población en pobreza por Calidad y Espacio de la Vivienda"
label var	pobre_ext_ccevj	 "Población en pobreza extrema por Calidad y Espacio de la Vivienda"
label var	E_CBDj	         "Estrato de carencia de Bienes Durables"
label var	pobreza_cbdj	 "Población en pobreza por Bienes Durables"
label var	pobre_ext_cbdj	 "Población en pobreza extrema por Bienes Durables"
label var	E_CSj	         "Estrato de Adecuación Sanitaria"
label var	pobreza_csj	     "Población en pobreza por Adecuación Sanitaria"
label var	pobre_ext_csj	 "Población en pobreza extrema por Adecuación Sanitaria"
label var	E_CTELJ	         "Estratos de carencia de Servicio de Telecomunicaciones"
label var	pobreza_ctelj	 "Población en pobreza por carencia de Servicio de Telecomunicaciones"
label var	pobre_ext_ctelj	 "Población en pobreza extrema por carencia de Servicio de Telecomunicaciones"
label var	E_CENJ	         "Estratos de carencia Energética"
label var	pobreza_cenj	 "Población en pobreza por carencia Energética"
label var	pobre_ext_cenj	 "Población en pobreza extrema por carencia Energética"
label var	E_rei	         "Estratos de Rezago Educativo"
label var	pobreza_rei	     "Población en pobreza por Rezago Educativo"
label var	pobre_ext_rei	 "Población en pobreza extrema por Rezago Educativo"
label var	E_CASSi	         "Estratos de acceso a Seguridad Social"
label var	pobreza_CASSi	 "Población en pobreza de acceso a Seguridad Social"
label var	pobre_ext_CASSi	 "Población en pobreza extrema de acceso a Seguridad Social"
label var	E_CASi	         "Estratos de acceso a Salud"
label var	pobreza_CASi	 "Población en pobreza de acceso a Salud"
label var	pobre_ext_CASi	 "Población en pobreza extrema de acceso a Salud"
label var	E_nbi	         "Estratos de Necesidades Básicas Insatisfechas"
label var	pobreza_nbi	     "Población en pobreza por NBI"
label var	pobre_ext_nbi	 "Población en pobreza extrema por NBI"
label var	E_cict	         "Estratos del ingreso"
label var	pobreza_cict	 "Población en pobreza por Ingreso"
label var	pobre_ext_cict	 "Población en pobreza extrema por Ingreso"
label var	E_CTL	         "Estratos del indicador de carencia de Tiempo Libre"
label var	pobreza_ctl	     "Población en pobreza por Tiempo Libre"
label var	pobre_ext_ctl	 "Población en pobreza extrema por Tiempo Libre"
label var	E_mmip	         "Estratos del MMIP"
label var	pobreza_mmip	 "Población en pobreza por MMIP"
label var	pobre_ext_mmip	 "Población en pobreza extrema por MMIP"
drop N_BREAK asegsoci_y asalud_y hablaesp comprenind 

*Ordenar
order folio folioviv foliohog ubica_geo	numren upm	est_dis	factor	parentesco	tam_loc	ur_rur_2500	tam_hog	      ///
      entidad municipio sexo edad edo_conyug etnia lenguaind hablaind alfabetism asis_esc nivel	nivelaprob        ///	
	  gradoaprob disc1 disc2 disc3 disc4 disc5 disc6 disc7 discapacidad	segpop                                    ///
	   inst_* segvol_2 tarifa_* mun_frio AMj ATj APj ACVj ADh CTBj AEVh AEVh_P HMDh ACEVj	CCEVj ABDj_P  ///  
	  CBDj AAj AFAj AAHj ADrj AEXj ASj CSj ATlj	Ij ACTI IVj	CTELJ AElj LFj_P LIEI PIEI ACK PCK AENj	CENj rescgeni ///	
	  ANEi ANEi_P Rei segsocial	salud Y_segsocial Y_salud  ASSi ASi CASSi CASi YIDj YISj YISj2                    ///
	  p009_ACN p016_ACN	ing_total remun_ACN	imp_viv_ACN	EBO_ACN	transf_ACN tran_gobACN tran_nogobACN renta_ACN    ///
	  g1p_gasto g4p_gasto g1h_gasto g3h_gasto renta_d dedu1 yctrj yctradj ing_men_hog ing_men_hog_stp ing_men_per ///	
	  ing_men_stp_per AE def_j000 LP_N ayj_LP decil_lp decil_lp_cdmx cyj_NLP nbi CTL1 MMIP 

*tabulados principales CDMX
foreach var of varlist E_mmip E_cict E_CTL E_nbi  E_ccevj ///
 E_CASi E_CASSi E_rei E_CBDj E_CSj  E_CENJ E_CTELJ    {
 tab `var'  [iw=factor] if entidad==09
 }
* 

*tabulados principales Nacional
foreach var of varlist E_mmip E_cict E_CTL E_nbi  E_ccevj ///
 E_CASi E_CASSi E_rei E_CBDj E_CSj  E_CENJ E_CTELJ    {
 tab `var'  [iw=factor] 
 }



save "$final/MMIP_2018.dta", replace 




